Class: Aws::GlueDataBrew::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::GlueDataBrew::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-gluedatabrew/client.rb,
sig/client.rbs
Overview
An API client for GlueDataBrew. To construct a client, you need to configure a :region and :credentials.
client = Aws::GlueDataBrew::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchDeleteRecipeVersionResponseSuccess, _CreateDatasetResponseSuccess, _CreateProfileJobResponseSuccess, _CreateProjectResponseSuccess, _CreateRecipeJobResponseSuccess, _CreateRecipeResponseSuccess, _CreateRulesetResponseSuccess, _CreateScheduleResponseSuccess, _DeleteDatasetResponseSuccess, _DeleteJobResponseSuccess, _DeleteProjectResponseSuccess, _DeleteRecipeVersionResponseSuccess, _DeleteRulesetResponseSuccess, _DeleteScheduleResponseSuccess, _DescribeDatasetResponseSuccess, _DescribeJobResponseSuccess, _DescribeJobRunResponseSuccess, _DescribeProjectResponseSuccess, _DescribeRecipeResponseSuccess, _DescribeRulesetResponseSuccess, _DescribeScheduleResponseSuccess, _ListDatasetsResponseSuccess, _ListJobRunsResponseSuccess, _ListJobsResponseSuccess, _ListProjectsResponseSuccess, _ListRecipeVersionsResponseSuccess, _ListRecipesResponseSuccess, _ListRulesetsResponseSuccess, _ListSchedulesResponseSuccess, _ListTagsForResourceResponseSuccess, _PublishRecipeResponseSuccess, _SendProjectSessionActionResponseSuccess, _StartJobRunResponseSuccess, _StartProjectSessionResponseSuccess, _StopJobRunResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateDatasetResponseSuccess, _UpdateProfileJobResponseSuccess, _UpdateProjectResponseSuccess, _UpdateRecipeJobResponseSuccess, _UpdateRecipeResponseSuccess, _UpdateRulesetResponseSuccess, _UpdateScheduleResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_delete_recipe_version(params = {}) ⇒ Types::BatchDeleteRecipeVersionResponse
Deletes one or more versions of a recipe at a time.
-
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new DataBrew dataset.
-
#create_profile_job(params = {}) ⇒ Types::CreateProfileJobResponse
Creates a new job to analyze a dataset and create its data profile.
-
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a new DataBrew project.
-
#create_recipe(params = {}) ⇒ Types::CreateRecipeResponse
Creates a new DataBrew recipe.
-
#create_recipe_job(params = {}) ⇒ Types::CreateRecipeJobResponse
Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe.
-
#create_ruleset(params = {}) ⇒ Types::CreateRulesetResponse
Creates a new ruleset that can be used in a profile job to validate the data quality of a dataset.
-
#create_schedule(params = {}) ⇒ Types::CreateScheduleResponse
Creates a new schedule for one or more DataBrew jobs.
-
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a dataset from DataBrew.
-
#delete_job(params = {}) ⇒ Types::DeleteJobResponse
Deletes the specified DataBrew job.
-
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes an existing DataBrew project.
-
#delete_recipe_version(params = {}) ⇒ Types::DeleteRecipeVersionResponse
Deletes a single version of a DataBrew recipe.
-
#delete_ruleset(params = {}) ⇒ Types::DeleteRulesetResponse
Deletes a ruleset.
-
#delete_schedule(params = {}) ⇒ Types::DeleteScheduleResponse
Deletes the specified DataBrew schedule.
-
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns the definition of a specific DataBrew dataset.
-
#describe_job(params = {}) ⇒ Types::DescribeJobResponse
Returns the definition of a specific DataBrew job.
-
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Represents one run of a DataBrew job.
-
#describe_project(params = {}) ⇒ Types::DescribeProjectResponse
Returns the definition of a specific DataBrew project.
-
#describe_recipe(params = {}) ⇒ Types::DescribeRecipeResponse
Returns the definition of a specific DataBrew recipe corresponding to a particular version.
-
#describe_ruleset(params = {}) ⇒ Types::DescribeRulesetResponse
Retrieves detailed information about the ruleset.
-
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Returns the definition of a specific DataBrew schedule.
-
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the DataBrew datasets.
-
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists all of the previous runs of a particular DataBrew job.
-
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists all of the DataBrew jobs that are defined.
-
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Lists all of the DataBrew projects that are defined.
-
#list_recipe_versions(params = {}) ⇒ Types::ListRecipeVersionsResponse
Lists the versions of a particular DataBrew recipe, except for
LATEST_WORKING. -
#list_recipes(params = {}) ⇒ Types::ListRecipesResponse
Lists all of the DataBrew recipes that are defined.
-
#list_rulesets(params = {}) ⇒ Types::ListRulesetsResponse
List all rulesets available in the current account or rulesets associated with a specific resource (dataset).
-
#list_schedules(params = {}) ⇒ Types::ListSchedulesResponse
Lists the DataBrew schedules that are defined.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags for a DataBrew resource.
-
#publish_recipe(params = {}) ⇒ Types::PublishRecipeResponse
Publishes a new version of a DataBrew recipe.
-
#send_project_session_action(params = {}) ⇒ Types::SendProjectSessionActionResponse
Performs a recipe step within an interactive DataBrew session that's currently open.
-
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Runs a DataBrew job.
-
#start_project_session(params = {}) ⇒ Types::StartProjectSessionResponse
Creates an interactive session, enabling you to manipulate data in a DataBrew project.
-
#stop_job_run(params = {}) ⇒ Types::StopJobRunResponse
Stops a particular run of a job.
-
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule.
-
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a DataBrew resource.
-
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Modifies the definition of an existing DataBrew dataset.
-
#update_profile_job(params = {}) ⇒ Types::UpdateProfileJobResponse
Modifies the definition of an existing profile job.
-
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Modifies the definition of an existing DataBrew project.
-
#update_recipe(params = {}) ⇒ Types::UpdateRecipeResponse
Modifies the definition of the
LATEST_WORKINGversion of a DataBrew recipe. -
#update_recipe_job(params = {}) ⇒ Types::UpdateRecipeJobResponse
Modifies the definition of an existing DataBrew recipe job.
-
#update_ruleset(params = {}) ⇒ Types::UpdateRulesetResponse
Updates specified ruleset.
-
#update_schedule(params = {}) ⇒ Types::UpdateScheduleResponse
Modifies the definition of an existing DataBrew schedule.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3461 3462 3463 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3461 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3464 3465 3466 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3464 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_delete_recipe_version(params = {}) ⇒ Types::BatchDeleteRecipeVersionResponse
Deletes one or more versions of a recipe at a time.
The entire request will be rejected if:
-
The recipe does not exist.
-
There is an invalid version identifier in the list of versions.
-
The version list is empty.
-
The version list size exceeds 50.
-
The version list contains duplicate entries.
The request will complete successfully, but with partial failures, if:
-
A version does not exist.
-
A version is being used by a job.
-
You specify
LATEST_WORKING, but it's being used by a project. -
The version fails to be deleted.
The LATEST_WORKING version will only be deleted if the recipe has no
other versions. If you try to delete LATEST_WORKING while other
versions exist (or if they can't be deleted), then LATEST_WORKING
will be listed as partial failure in the response.
87 |
# File 'sig/client.rbs', line 87
def batch_delete_recipe_version: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3434 3435 3436 3437 3438 3439 3440 3441 3442 3443 3444 3445 3446 3447 3448 3449 3450 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3434 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::GlueDataBrew') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-gluedatabrew' context[:gem_version] = '1.74.0' Seahorse::Client::Request.new(handlers, context) end |
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new DataBrew dataset.
98 |
# File 'sig/client.rbs', line 98
def create_dataset: (
|
#create_profile_job(params = {}) ⇒ Types::CreateProfileJobResponse
Creates a new job to analyze a dataset and create its data profile.
113 |
# File 'sig/client.rbs', line 113
def create_profile_job: (
|
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a new DataBrew project.
148 |
# File 'sig/client.rbs', line 148
def create_project: (
|
#create_recipe(params = {}) ⇒ Types::CreateRecipeResponse
Creates a new DataBrew recipe.
166 |
# File 'sig/client.rbs', line 166
def create_recipe: (
|
#create_recipe_job(params = {}) ⇒ Types::CreateRecipeJobResponse
Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe
181 |
# File 'sig/client.rbs', line 181
def create_recipe_job: (
|
#create_ruleset(params = {}) ⇒ Types::CreateRulesetResponse
Creates a new ruleset that can be used in a profile job to validate the data quality of a dataset.
214 |
# File 'sig/client.rbs', line 214
def create_ruleset: (
|
#create_schedule(params = {}) ⇒ Types::CreateScheduleResponse
Creates a new schedule for one or more DataBrew jobs. Jobs can be run at a specific date and time, or at regular intervals.
230 |
# File 'sig/client.rbs', line 230
def create_schedule: (
|
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a dataset from DataBrew.
243 |
# File 'sig/client.rbs', line 243
def delete_dataset: (
|
#delete_job(params = {}) ⇒ Types::DeleteJobResponse
Deletes the specified DataBrew job.
253 |
# File 'sig/client.rbs', line 253
def delete_job: (
|
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes an existing DataBrew project.
263 |
# File 'sig/client.rbs', line 263
def delete_project: (
|
#delete_recipe_version(params = {}) ⇒ Types::DeleteRecipeVersionResponse
Deletes a single version of a DataBrew recipe.
274 |
# File 'sig/client.rbs', line 274
def delete_recipe_version: (
|
#delete_ruleset(params = {}) ⇒ Types::DeleteRulesetResponse
Deletes a ruleset.
285 |
# File 'sig/client.rbs', line 285
def delete_ruleset: (
|
#delete_schedule(params = {}) ⇒ Types::DeleteScheduleResponse
Deletes the specified DataBrew schedule.
295 |
# File 'sig/client.rbs', line 295
def delete_schedule: (
|
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns the definition of a specific DataBrew dataset.
316 |
# File 'sig/client.rbs', line 316
def describe_dataset: (
|
#describe_job(params = {}) ⇒ Types::DescribeJobResponse
Returns the definition of a specific DataBrew job.
349 |
# File 'sig/client.rbs', line 349
def describe_job: (
|
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Represents one run of a DataBrew job.
377 |
# File 'sig/client.rbs', line 377
def describe_job_run: (
|
#describe_project(params = {}) ⇒ Types::DescribeProjectResponse
Returns the definition of a specific DataBrew project.
401 |
# File 'sig/client.rbs', line 401
def describe_project: (
|
#describe_recipe(params = {}) ⇒ Types::DescribeRecipeResponse
Returns the definition of a specific DataBrew recipe corresponding to a particular version.
423 |
# File 'sig/client.rbs', line 423
def describe_recipe: (
|
#describe_ruleset(params = {}) ⇒ Types::DescribeRulesetResponse
Retrieves detailed information about the ruleset.
443 |
# File 'sig/client.rbs', line 443
def describe_ruleset: (
|
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Returns the definition of a specific DataBrew schedule.
461 |
# File 'sig/client.rbs', line 461
def describe_schedule: (
|
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the DataBrew datasets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
472 |
# File 'sig/client.rbs', line 472
def list_datasets: (
|
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists all of the previous runs of a particular DataBrew job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
484 |
# File 'sig/client.rbs', line 484
def list_job_runs: (
|
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists all of the DataBrew jobs that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
497 |
# File 'sig/client.rbs', line 497
def list_jobs: (
|
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Lists all of the DataBrew projects that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
511 |
# File 'sig/client.rbs', line 511
def list_projects: (
|
#list_recipe_versions(params = {}) ⇒ Types::ListRecipeVersionsResponse
Lists the versions of a particular DataBrew recipe, except for
LATEST_WORKING.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
523 |
# File 'sig/client.rbs', line 523
def list_recipe_versions: (
|
#list_recipes(params = {}) ⇒ Types::ListRecipesResponse
Lists all of the DataBrew recipes that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
536 |
# File 'sig/client.rbs', line 536
def list_recipes: (
|
#list_rulesets(params = {}) ⇒ Types::ListRulesetsResponse
List all rulesets available in the current account or rulesets associated with a specific resource (dataset).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
549 |
# File 'sig/client.rbs', line 549
def list_rulesets: (
|
#list_schedules(params = {}) ⇒ Types::ListSchedulesResponse
Lists the DataBrew schedules that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
562 |
# File 'sig/client.rbs', line 562
def list_schedules: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags for a DataBrew resource.
574 |
# File 'sig/client.rbs', line 574
def list_tags_for_resource: (
|
#publish_recipe(params = {}) ⇒ Types::PublishRecipeResponse
Publishes a new version of a DataBrew recipe.
584 |
# File 'sig/client.rbs', line 584
def publish_recipe: (
|
#send_project_session_action(params = {}) ⇒ Types::SendProjectSessionActionResponse
Performs a recipe step within an interactive DataBrew session that's currently open.
597 |
# File 'sig/client.rbs', line 597
def send_project_session_action: (
|
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Runs a DataBrew job.
619 |
# File 'sig/client.rbs', line 619
def start_job_run: (
|
#start_project_session(params = {}) ⇒ Types::StartProjectSessionResponse
Creates an interactive session, enabling you to manipulate data in a DataBrew project.
630 |
# File 'sig/client.rbs', line 630
def start_project_session: (
|
#stop_job_run(params = {}) ⇒ Types::StopJobRunResponse
Stops a particular run of a job.
641 |
# File 'sig/client.rbs', line 641
def stop_job_run: (
|
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule.
651 |
# File 'sig/client.rbs', line 651
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a DataBrew resource.
661 |
# File 'sig/client.rbs', line 661
def untag_resource: (
|
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Modifies the definition of an existing DataBrew dataset.
672 |
# File 'sig/client.rbs', line 672
def update_dataset: (
|
#update_profile_job(params = {}) ⇒ Types::UpdateProfileJobResponse
Modifies the definition of an existing profile job.
686 |
# File 'sig/client.rbs', line 686
def update_profile_job: (
|
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Modifies the definition of an existing DataBrew project.
720 |
# File 'sig/client.rbs', line 720
def update_project: (
|
#update_recipe(params = {}) ⇒ Types::UpdateRecipeResponse
Modifies the definition of the LATEST_WORKING version of a DataBrew
recipe.
735 |
# File 'sig/client.rbs', line 735
def update_recipe: (
|
#update_recipe_job(params = {}) ⇒ Types::UpdateRecipeJobResponse
Modifies the definition of an existing DataBrew recipe job.
749 |
# File 'sig/client.rbs', line 749
def update_recipe_job: (
|
#update_ruleset(params = {}) ⇒ Types::UpdateRulesetResponse
Updates specified ruleset.
775 |
# File 'sig/client.rbs', line 775
def update_ruleset: (
|
#update_schedule(params = {}) ⇒ Types::UpdateScheduleResponse
Modifies the definition of an existing DataBrew schedule.
789 |
# File 'sig/client.rbs', line 789
def update_schedule: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3454 3455 3456 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3454 def waiter_names [] end |