Class: Aws::GlueDataBrew::Types::BatchDeleteRecipeVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::BatchDeleteRecipeVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Note:
When making an API call, you may pass BatchDeleteRecipeVersionRequest data as a hash:
{
name: "RecipeName", # required
recipe_versions: ["RecipeVersion"], # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the recipe whose versions are to be deleted.
-
#recipe_versions ⇒ Array<String>
An array of version identifiers, for the recipe versions to be deleted.
Instance Attribute Details
#name ⇒ String
The name of the recipe whose versions are to be deleted.
70 71 72 73 74 75 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 70 class BatchDeleteRecipeVersionRequest < Struct.new( :name, :recipe_versions) SENSITIVE = [] include Aws::Structure end |
#recipe_versions ⇒ Array<String>
An array of version identifiers, for the recipe versions to be deleted. You can specify numeric versions (`X.Y`) or `LATEST_WORKING`. `LATEST_PUBLISHED` is not supported.
70 71 72 73 74 75 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 70 class BatchDeleteRecipeVersionRequest < Struct.new( :name, :recipe_versions) SENSITIVE = [] include Aws::Structure end |