Class: Aws::GlueDataBrew::Types::ConditionExpression
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::ConditionExpression
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
When making an API call, you may pass ConditionExpression data as a hash:
{
condition: "Condition", # required
value: "ConditionValue",
target_column: "TargetColumn", # required
}
Represents an individual condition that evaluates to true or false.
Conditions are used with recipe actions. The action is only performed for column values where the condition evaluates to true.
If a recipe requires more than one condition, then the recipe must specify multiple `ConditionExpression` elements. Each condition is applied to the rows in a dataset first, before the recipe action is performed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#condition ⇒ String
A specific condition to apply to a recipe action.
-
#target_column ⇒ String
A column to apply this condition to.
-
#value ⇒ String
A value that the condition must evaluate to for the condition to succeed.
Instance Attribute Details
#condition ⇒ String
A specific condition to apply to a recipe action. For more information, see [Recipe structure] in the *Glue DataBrew Developer Guide*.
[1]: docs.aws.amazon.com/databrew/latest/dg/recipes.html#recipes.structure
210 211 212 213 214 215 216 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 210 class ConditionExpression < Struct.new( :condition, :value, :target_column) SENSITIVE = [] include Aws::Structure end |
#target_column ⇒ String
A column to apply this condition to.
210 211 212 213 214 215 216 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 210 class ConditionExpression < Struct.new( :condition, :value, :target_column) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
A value that the condition must evaluate to for the condition to succeed.
210 211 212 213 214 215 216 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 210 class ConditionExpression < Struct.new( :condition, :value, :target_column) SENSITIVE = [] include Aws::Structure end |