Class: Aws::GlueDataBrew::Types::CreateProfileJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::CreateProfileJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
When making an API call, you may pass CreateProfileJobRequest data as a hash:
{
dataset_name: "DatasetName", # required
encryption_key_arn: "EncryptionKeyArn",
encryption_mode: "SSE-KMS", # accepts SSE-KMS, SSE-S3
name: "JobName", # required
log_subscription: "ENABLE", # accepts ENABLE, DISABLE
max_capacity: 1,
max_retries: 1,
output_location: { # required
bucket: "Bucket", # required
key: "Key",
bucket_owner: "BucketOwner",
},
configuration: {
dataset_statistics_configuration: {
included_statistics: ["Statistic"],
overrides: [
{
statistic: "Statistic", # required
parameters: { # required
"ParameterName" => "ParameterValue",
},
},
],
},
profile_columns: [
{
regex: "ColumnName",
name: "ColumnName",
},
],
column_statistics_configurations: [
{
selectors: [
{
regex: "ColumnName",
name: "ColumnName",
},
],
statistics: { # required
included_statistics: ["Statistic"],
overrides: [
{
statistic: "Statistic", # required
parameters: { # required
"ParameterName" => "ParameterValue",
},
},
],
},
},
],
entity_detector_configuration: {
entity_types: ["EntityType"], # required
allowed_statistics: [
{
statistics: ["Statistic"], # required
},
],
},
},
validation_configurations: [
{
ruleset_arn: "Arn", # required
validation_mode: "CHECK_ALL", # accepts CHECK_ALL
},
],
role_arn: "Arn", # required
tags: {
"TagKey" => "TagValue",
},
timeout: 1,
job_sample: {
mode: "FULL_DATASET", # accepts FULL_DATASET, CUSTOM_ROWS
size: 1,
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Types::ProfileConfiguration
Configuration for profile jobs.
-
#dataset_name ⇒ String
The name of the dataset that this job is to act upon.
-
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of an encryption key that is used to protect the job.
-
#encryption_mode ⇒ String
The encryption mode for the job, which can be one of the following:.
-
#job_sample ⇒ Types::JobSample
Sample configuration for profile jobs only.
-
#log_subscription ⇒ String
Enables or disables Amazon CloudWatch logging for the job.
-
#max_capacity ⇒ Integer
The maximum number of nodes that DataBrew can use when the job processes data.
-
#max_retries ⇒ Integer
The maximum number of times to retry the job after a job run fails.
-
#name ⇒ String
The name of the job to be created.
-
#output_location ⇒ Types::S3Location
Represents an Amazon S3 location (bucket name, bucket owner, and object key) where DataBrew can read input data, or write output from a job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role to be assumed when DataBrew runs the job.
-
#tags ⇒ Hash<String,String>
Metadata tags to apply to this job.
-
#timeout ⇒ Integer
The job's timeout in minutes.
-
#validation_configurations ⇒ Array<Types::ValidationConfiguration>
List of validation configurations that are applied to the profile job.
Instance Attribute Details
#configuration ⇒ Types::ProfileConfiguration
Configuration for profile jobs. Used to select columns, do evaluations, and override default parameters of evaluations. When configuration is null, the profile job will run with default settings.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#dataset_name ⇒ String
The name of the dataset that this job is to act upon.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of an encryption key that is used to protect the job.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#encryption_mode ⇒ String
The encryption mode for the job, which can be one of the following:
-
`SSE-KMS` - `SSE-KMS` - Server-side encryption with KMS-managed keys.
-
`SSE-S3` - Server-side encryption with keys managed by Amazon S3.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#job_sample ⇒ Types::JobSample
Sample configuration for profile jobs only. Determines the number of rows on which the profile job will be executed. If a JobSample value is not provided, the default value will be used. The default value is CUSTOM_ROWS for the mode parameter and 20000 for the size parameter.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#log_subscription ⇒ String
Enables or disables Amazon CloudWatch logging for the job. If logging is enabled, CloudWatch writes one log stream for each job run.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Integer
The maximum number of nodes that DataBrew can use when the job processes data.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#max_retries ⇒ Integer
The maximum number of times to retry the job after a job run fails.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the job to be created. Valid characters are alphanumeric (A-Z, a-z, 0-9), hyphen (-), period (.), and space.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#output_location ⇒ Types::S3Location
Represents an Amazon S3 location (bucket name, bucket owner, and object key) where DataBrew can read input data, or write output from a job.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role to be assumed when DataBrew runs the job.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata tags to apply to this job.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The job's timeout in minutes. A job that attempts to run longer than this timeout period ends with a status of `TIMEOUT`.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#validation_configurations ⇒ Array<Types::ValidationConfiguration>
List of validation configurations that are applied to the profile job.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 532 class CreateProfileJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :output_location, :configuration, :validation_configurations, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |