Class: Aws::GlueDataBrew::Types::CreateRecipeJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gluedatabrew/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_catalog_outputs ⇒ Array<Types::DataCatalogOutput>

One or more artifacts that represent the Glue Data Catalog output from running the job.

Returns:



470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#database_outputs ⇒ Array<Types::DatabaseOutput>

Represents a list of JDBC database output objects which defines the output destination for a DataBrew recipe job to write to.

Returns:



470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_name ⇒ String

The name of the dataset that this job processes.

Returns:

  • (String)


470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_key_arn ⇒ String

The Amazon Resource Name (ARN) of an encryption key that is used to protect the job.

Returns:

  • (String)


470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_mode ⇒ String

The encryption mode for the job, which can be one of the following:

  • SSE-KMS - Server-side encryption with keys managed by KMS.

  • SSE-S3 - Server-side encryption with keys managed by Amazon S3.

Returns:

  • (String)


470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#log_subscription ⇒ String

Enables or disables Amazon CloudWatch logging for the job. If logging is enabled, CloudWatch writes one log stream for each job run.

Returns:

  • (String)


470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacity ⇒ Integer

The maximum number of nodes that DataBrew can consume when the job processes data.

Returns:

  • (Integer)


470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#max_retries ⇒ Integer

The maximum number of times to retry the job after a job run fails.

Returns:

  • (Integer)


470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

A unique name for the job. Valid characters are alphanumeric (A-Z, a-z, 0-9), hyphen (-), period (.), and space.

Returns:

  • (String)


470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#outputs ⇒ Array<Types::Output>

One or more artifacts that represent the output from running the job.

Returns:



470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#project_name ⇒ String

Either the name of an existing project, or a combination of a recipe and a dataset to associate with the recipe.

Returns:

  • (String)


470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#recipe_reference ⇒ Types::RecipeReference

Represents the name and version of a DataBrew recipe.



470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role to be assumed when DataBrew runs the job.

Returns:

  • (String)


470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

Metadata tags to apply to this job.

Returns:

  • (Hash<String,String>)


470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end

#timeout ⇒ Integer

The job's timeout in minutes. A job that attempts to run longer than this timeout period ends with a status of TIMEOUT.

Returns:

  • (Integer)


470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 470

class CreateRecipeJobRequest < Struct.new(
  :dataset_name,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :outputs,
  :data_catalog_outputs,
  :database_outputs,
  :project_name,
  :recipe_reference,
  :role_arn,
  :tags,
  :timeout)
  SENSITIVE = []
  include Aws::Structure
end