Class: Aws::GlueDataBrew::Types::CreateScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::CreateScheduleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Note:
When making an API call, you may pass CreateScheduleRequest data as a hash:
{
job_names: ["JobName"],
cron_expression: "CronExpression", # required
tags: {
"TagKey" => "TagValue",
},
name: "ScheduleName", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cron_expression ⇒ String
The date or dates and time or times when the jobs are to be run.
-
#job_names ⇒ Array<String>
The name or names of one or more jobs to be run.
-
#name ⇒ String
A unique name for the schedule.
-
#tags ⇒ Hash<String,String>
Metadata tags to apply to this schedule.
Instance Attribute Details
#cron_expression ⇒ String
The date or dates and time or times when the jobs are to be run. For more information, see [Cron expressions] in the *Glue DataBrew Developer Guide*.
1007 1008 1009 1010 1011 1012 1013 1014 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1007 class CreateScheduleRequest < Struct.new( :job_names, :cron_expression, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#job_names ⇒ Array<String>
The name or names of one or more jobs to be run.
1007 1008 1009 1010 1011 1012 1013 1014 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1007 class CreateScheduleRequest < Struct.new( :job_names, :cron_expression, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A unique name for the schedule. Valid characters are alphanumeric (A-Z, a-z, 0-9), hyphen (-), period (.), and space.
1007 1008 1009 1010 1011 1012 1013 1014 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1007 class CreateScheduleRequest < Struct.new( :job_names, :cron_expression, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata tags to apply to this schedule.
1007 1008 1009 1010 1011 1012 1013 1014 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1007 class CreateScheduleRequest < Struct.new( :job_names, :cron_expression, :tags, :name) SENSITIVE = [] include Aws::Structure end |