Class: Aws::GlueDataBrew::Types::DatetimeOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::DatetimeOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
When making an API call, you may pass DatetimeOptions data as a hash:
{
format: "DatetimeFormat", # required
timezone_offset: "TimezoneOffset",
locale_code: "LocaleCode",
}
Represents additional options for correct interpretation of datetime parameters used in the Amazon S3 path of a dataset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#format ⇒ String
Required option, that defines the datetime format used for a date parameter in the Amazon S3 path.
-
#locale_code ⇒ String
Optional value for a non-US locale code, needed for correct interpretation of some date formats.
-
#timezone_offset ⇒ String
Optional value for a timezone offset of the datetime parameter value in the Amazon S3 path.
Instance Attribute Details
#format ⇒ String
Required option, that defines the datetime format used for a date parameter in the Amazon S3 path. Should use only supported datetime specifiers and separation characters, all literal a-z or A-Z characters should be escaped with single quotes. E.g. “MM.dd.yyyy-'at'-HH:mm”.
1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1499 class DatetimeOptions < Struct.new( :format, :timezone_offset, :locale_code) SENSITIVE = [] include Aws::Structure end |
#locale_code ⇒ String
Optional value for a non-US locale code, needed for correct interpretation of some date formats.
1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1499 class DatetimeOptions < Struct.new( :format, :timezone_offset, :locale_code) SENSITIVE = [] include Aws::Structure end |
#timezone_offset ⇒ String
Optional value for a timezone offset of the datetime parameter value in the Amazon S3 path. Shouldn't be used if Format for this parameter includes timezone fields. If no offset specified, UTC is assumed.
1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1499 class DatetimeOptions < Struct.new( :format, :timezone_offset, :locale_code) SENSITIVE = [] include Aws::Structure end |