Class: Aws::GlueDataBrew::Types::DescribeJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::DescribeJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_date ⇒ Time
The date and time that the job was created.
-
#created_by ⇒ String
The identifier (user name) of the user associated with the creation of the job.
-
#data_catalog_outputs ⇒ Array<Types::DataCatalogOutput>
One or more artifacts that represent the Glue Data Catalog output from running the job.
-
#database_outputs ⇒ Array<Types::DatabaseOutput>
Represents a list of JDBC database output objects which defines the output destination for a DataBrew recipe job to write into.
-
#dataset_name ⇒ String
The dataset that the job acts upon.
-
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of an encryption key that is used to protect the job.
-
#encryption_mode ⇒ String
The encryption mode for the job, which can be one of the following:.
-
#job_sample ⇒ Types::JobSample
Sample configuration for profile jobs only.
-
#last_modified_by ⇒ String
The identifier (user name) of the user who last modified the job.
-
#last_modified_date ⇒ Time
The date and time that the job was last modified.
-
#log_subscription ⇒ String
Indicates whether Amazon CloudWatch logging is enabled for this job.
-
#max_capacity ⇒ Integer
The maximum number of compute nodes that DataBrew can consume when the job processes data.
-
#max_retries ⇒ Integer
The maximum number of times to retry the job after a job run fails.
-
#name ⇒ String
The name of the job.
-
#outputs ⇒ Array<Types::Output>
One or more artifacts that represent the output from running the job.
-
#profile_configuration ⇒ Types::ProfileConfiguration
Configuration for profile jobs.
-
#project_name ⇒ String
The DataBrew project associated with this job.
-
#recipe_reference ⇒ Types::RecipeReference
Represents the name and version of a DataBrew recipe.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the job.
-
#role_arn ⇒ String
The ARN of the Identity and Access Management (IAM) role to be assumed when DataBrew runs the job.
-
#tags ⇒ Hash<String,String>
Metadata tags associated with this job.
-
#timeout ⇒ Integer
The job's timeout in minutes.
-
#type ⇒ String
The job type, which must be one of the following:.
-
#validation_configurations ⇒ Array<Types::ValidationConfiguration>
List of validation configurations that are applied to the profile job.
Instance Attribute Details
#create_date ⇒ Time
The date and time that the job was created.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The identifier (user name) of the user associated with the creation of the job.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#data_catalog_outputs ⇒ Array<Types::DataCatalogOutput>
One or more artifacts that represent the Glue Data Catalog output from running the job.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#database_outputs ⇒ Array<Types::DatabaseOutput>
Represents a list of JDBC database output objects which defines the output destination for a DataBrew recipe job to write into.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#dataset_name ⇒ String
The dataset that the job acts upon.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of an encryption key that is used to protect the job.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#encryption_mode ⇒ String
The encryption mode for the job, which can be one of the following:
-
`SSE-KMS` - Server-side encryption with keys managed by KMS.
-
`SSE-S3` - Server-side encryption with keys managed by Amazon S3.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#job_sample ⇒ Types::JobSample
Sample configuration for profile jobs only. Determines the number of rows on which the profile job will be executed.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ String
The identifier (user name) of the user who last modified the job.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date and time that the job was last modified.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#log_subscription ⇒ String
Indicates whether Amazon CloudWatch logging is enabled for this job.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Integer
The maximum number of compute nodes that DataBrew can consume when the job processes data.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#max_retries ⇒ Integer
The maximum number of times to retry the job after a job run fails.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the job.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::Output>
One or more artifacts that represent the output from running the job.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#profile_configuration ⇒ Types::ProfileConfiguration
Configuration for profile jobs. Used to select columns, do evaluations, and override default parameters of evaluations. When configuration is null, the profile job will run with default settings.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
The DataBrew project associated with this job.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#recipe_reference ⇒ Types::RecipeReference
Represents the name and version of a DataBrew recipe.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the job.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the Identity and Access Management (IAM) role to be assumed when DataBrew runs the job.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata tags associated with this job.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The job's timeout in minutes. A job that attempts to run longer than this timeout period ends with a status of `TIMEOUT`.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The job type, which must be one of the following:
-
`PROFILE` - The job analyzes the dataset to determine its size, data types, data distribution, and more.
-
`RECIPE` - The job applies one or more transformations to a dataset.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |
#validation_configurations ⇒ Array<Types::ValidationConfiguration>
List of validation configurations that are applied to the profile job.
1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1938 class DescribeJobResponse < Struct.new( :create_date, :created_by, :dataset_name, :encryption_key_arn, :encryption_mode, :name, :type, :last_modified_by, :last_modified_date, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :profile_configuration, :validation_configurations, :recipe_reference, :resource_arn, :role_arn, :tags, :timeout, :job_sample) SENSITIVE = [] include Aws::Structure end |