Class: Aws::GlueDataBrew::Types::DescribeJobRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::DescribeJobRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Note:
When making an API call, you may pass DescribeJobRunRequest data as a hash:
{
name: "JobName", # required
run_id: "JobRunId", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the job being processed during this run.
-
#run_id ⇒ String
The unique identifier of the job run.
Instance Attribute Details
#name ⇒ String
The name of the job being processed during this run.
1984 1985 1986 1987 1988 1989 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1984 class DescribeJobRunRequest < Struct.new( :name, :run_id) SENSITIVE = [] include Aws::Structure end |
#run_id ⇒ String
The unique identifier of the job run.
1984 1985 1986 1987 1988 1989 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1984 class DescribeJobRunRequest < Struct.new( :name, :run_id) SENSITIVE = [] include Aws::Structure end |