Class: Aws::GlueDataBrew::Types::DescribeJobRunResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::DescribeJobRunResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attempt ⇒ Integer
The number of times that DataBrew has attempted to run the job.
-
#completed_on ⇒ Time
The date and time when the job completed processing.
-
#data_catalog_outputs ⇒ Array<Types::DataCatalogOutput>
One or more artifacts that represent the Glue Data Catalog output from running the job.
-
#database_outputs ⇒ Array<Types::DatabaseOutput>
Represents a list of JDBC database output objects which defines the output destination for a DataBrew recipe job to write into.
-
#dataset_name ⇒ String
The name of the dataset for the job to process.
-
#error_message ⇒ String
A message indicating an error (if any) that was encountered when the job ran.
-
#execution_time ⇒ Integer
The amount of time, in seconds, during which the job run consumed resources.
-
#job_name ⇒ String
The name of the job being processed during this run.
-
#job_sample ⇒ Types::JobSample
Sample configuration for profile jobs only.
-
#log_group_name ⇒ String
The name of an Amazon CloudWatch log group, where the job writes diagnostic messages when it runs.
-
#log_subscription ⇒ String
The current status of Amazon CloudWatch logging for the job run.
-
#outputs ⇒ Array<Types::Output>
One or more output artifacts from a job run.
-
#profile_configuration ⇒ Types::ProfileConfiguration
Configuration for profile jobs.
-
#recipe_reference ⇒ Types::RecipeReference
Represents the name and version of a DataBrew recipe.
-
#run_id ⇒ String
The unique identifier of the job run.
-
#started_by ⇒ String
The Amazon Resource Name (ARN) of the user who started the job run.
-
#started_on ⇒ Time
The date and time when the job run began.
-
#state ⇒ String
The current state of the job run entity itself.
-
#validation_configurations ⇒ Array<Types::ValidationConfiguration>
List of validation configurations that are applied to the profile job.
Instance Attribute Details
#attempt ⇒ Integer
The number of times that DataBrew has attempted to run the job.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#completed_on ⇒ Time
The date and time when the job completed processing.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#data_catalog_outputs ⇒ Array<Types::DataCatalogOutput>
One or more artifacts that represent the Glue Data Catalog output from running the job.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#database_outputs ⇒ Array<Types::DatabaseOutput>
Represents a list of JDBC database output objects which defines the output destination for a DataBrew recipe job to write into.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#dataset_name ⇒ String
The name of the dataset for the job to process.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
A message indicating an error (if any) that was encountered when the job ran.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#execution_time ⇒ Integer
The amount of time, in seconds, during which the job run consumed resources.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the job being processed during this run.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#job_sample ⇒ Types::JobSample
Sample configuration for profile jobs only. Determines the number of rows on which the profile job will be executed. If a JobSample value is not provided, the default value will be used. The default value is CUSTOM_ROWS for the mode parameter and 20000 for the size parameter.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of an Amazon CloudWatch log group, where the job writes diagnostic messages when it runs.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#log_subscription ⇒ String
The current status of Amazon CloudWatch logging for the job run.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::Output>
One or more output artifacts from a job run.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#profile_configuration ⇒ Types::ProfileConfiguration
Configuration for profile jobs. Used to select columns, do evaluations, and override default parameters of evaluations. When configuration is null, the profile job will run with default settings.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#recipe_reference ⇒ Types::RecipeReference
Represents the name and version of a DataBrew recipe.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#run_id ⇒ String
The unique identifier of the job run.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#started_by ⇒ String
The Amazon Resource Name (ARN) of the user who started the job run.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#started_on ⇒ Time
The date and time when the job run began.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the job run entity itself.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |
#validation_configurations ⇒ Array<Types::ValidationConfiguration>
List of validation configurations that are applied to the profile job.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2082 class DescribeJobRunResponse < Struct.new( :attempt, :completed_on, :dataset_name, :error_message, :execution_time, :job_name, :profile_configuration, :validation_configurations, :run_id, :state, :log_subscription, :log_group_name, :outputs, :data_catalog_outputs, :database_outputs, :recipe_reference, :started_by, :started_on, :job_sample) SENSITIVE = [] include Aws::Structure end |