Class: Aws::GlueDataBrew::Types::DescribeRecipeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::DescribeRecipeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_date ⇒ Time
The date and time that the recipe was created.
-
#created_by ⇒ String
The identifier (user name) of the user who created the recipe.
-
#description ⇒ String
The description of the recipe.
-
#last_modified_by ⇒ String
The identifier (user name) of the user who last modified the recipe.
-
#last_modified_date ⇒ Time
The date and time that the recipe was last modified.
-
#name ⇒ String
The name of the recipe.
-
#project_name ⇒ String
The name of the project associated with this recipe.
-
#published_by ⇒ String
The identifier (user name) of the user who last published the recipe.
-
#published_date ⇒ Time
The date and time when the recipe was last published.
-
#recipe_version ⇒ String
The recipe version identifier.
-
#resource_arn ⇒ String
The ARN of the recipe.
-
#steps ⇒ Array<Types::RecipeStep>
One or more steps to be performed by the recipe.
-
#tags ⇒ Hash<String,String>
Metadata tags associated with this project.
Instance Attribute Details
#create_date ⇒ Time
The date and time that the recipe was created.
2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2296 class DescribeRecipeResponse < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :steps, :tags, :resource_arn, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The identifier (user name) of the user who created the recipe.
2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2296 class DescribeRecipeResponse < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :steps, :tags, :resource_arn, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the recipe.
2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2296 class DescribeRecipeResponse < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :steps, :tags, :resource_arn, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ String
The identifier (user name) of the user who last modified the recipe.
2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2296 class DescribeRecipeResponse < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :steps, :tags, :resource_arn, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date and time that the recipe was last modified.
2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2296 class DescribeRecipeResponse < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :steps, :tags, :resource_arn, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the recipe.
2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2296 class DescribeRecipeResponse < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :steps, :tags, :resource_arn, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
The name of the project associated with this recipe.
2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2296 class DescribeRecipeResponse < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :steps, :tags, :resource_arn, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#published_by ⇒ String
The identifier (user name) of the user who last published the recipe.
2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2296 class DescribeRecipeResponse < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :steps, :tags, :resource_arn, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#published_date ⇒ Time
The date and time when the recipe was last published.
2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2296 class DescribeRecipeResponse < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :steps, :tags, :resource_arn, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#recipe_version ⇒ String
The recipe version identifier.
2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2296 class DescribeRecipeResponse < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :steps, :tags, :resource_arn, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The ARN of the recipe.
2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2296 class DescribeRecipeResponse < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :steps, :tags, :resource_arn, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#steps ⇒ Array<Types::RecipeStep>
One or more steps to be performed by the recipe. Each step consists of an action, and the conditions under which the action should succeed.
2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2296 class DescribeRecipeResponse < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :steps, :tags, :resource_arn, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata tags associated with this project.
2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2296 class DescribeRecipeResponse < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :steps, :tags, :resource_arn, :recipe_version) SENSITIVE = [] include Aws::Structure end |