Class: Aws::GlueDataBrew::Types::DescribeScheduleResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gluedatabrew/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#create_date ⇒ Time

The date and time that the schedule was created.

Returns:

  • (Time)


1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1848

class DescribeScheduleResponse < Struct.new(
  :create_date,
  :created_by,
  :job_names,
  :last_modified_by,
  :last_modified_date,
  :resource_arn,
  :cron_expression,
  :tags,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#created_by ⇒ String

The identifier (user name) of the user who created the schedule.

Returns:

  • (String)


1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1848

class DescribeScheduleResponse < Struct.new(
  :create_date,
  :created_by,
  :job_names,
  :last_modified_by,
  :last_modified_date,
  :resource_arn,
  :cron_expression,
  :tags,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#cron_expression ⇒ String

The date or dates and time or times when the jobs are to be run for the schedule. For more information, see Cron expressions in the Glue DataBrew Developer Guide.

Returns:

  • (String)


1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1848

class DescribeScheduleResponse < Struct.new(
  :create_date,
  :created_by,
  :job_names,
  :last_modified_by,
  :last_modified_date,
  :resource_arn,
  :cron_expression,
  :tags,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#job_names ⇒ Array<String>

The name or names of one or more jobs to be run by using the schedule.

Returns:

  • (Array<String>)


1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1848

class DescribeScheduleResponse < Struct.new(
  :create_date,
  :created_by,
  :job_names,
  :last_modified_by,
  :last_modified_date,
  :resource_arn,
  :cron_expression,
  :tags,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_by ⇒ String

The identifier (user name) of the user who last modified the schedule.

Returns:

  • (String)


1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1848

class DescribeScheduleResponse < Struct.new(
  :create_date,
  :created_by,
  :job_names,
  :last_modified_by,
  :last_modified_date,
  :resource_arn,
  :cron_expression,
  :tags,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_date ⇒ Time

The date and time that the schedule was last modified.

Returns:

  • (Time)


1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1848

class DescribeScheduleResponse < Struct.new(
  :create_date,
  :created_by,
  :job_names,
  :last_modified_by,
  :last_modified_date,
  :resource_arn,
  :cron_expression,
  :tags,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the schedule.

Returns:

  • (String)


1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1848

class DescribeScheduleResponse < Struct.new(
  :create_date,
  :created_by,
  :job_names,
  :last_modified_by,
  :last_modified_date,
  :resource_arn,
  :cron_expression,
  :tags,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arn ⇒ String

The Amazon Resource Name (ARN) of the schedule.

Returns:

  • (String)


1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1848

class DescribeScheduleResponse < Struct.new(
  :create_date,
  :created_by,
  :job_names,
  :last_modified_by,
  :last_modified_date,
  :resource_arn,
  :cron_expression,
  :tags,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

Metadata tags associated with this schedule.

Returns:

  • (Hash<String,String>)


1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 1848

class DescribeScheduleResponse < Struct.new(
  :create_date,
  :created_by,
  :job_names,
  :last_modified_by,
  :last_modified_date,
  :resource_arn,
  :cron_expression,
  :tags,
  :name)
  SENSITIVE = []
  include Aws::Structure
end