Class: Aws::GlueDataBrew::Types::EntityDetectorConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::EntityDetectorConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
When making an API call, you may pass EntityDetectorConfiguration data as a hash:
{
entity_types: ["EntityType"], # required
allowed_statistics: [
{
statistics: ["Statistic"], # required
},
],
}
Configuration of entity detection for a profile job. When undefined, entity detection is disabled.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_statistics ⇒ Array<Types::AllowedStatistics>
Configuration of statistics that are allowed to be run on columns that contain detected entities.
-
#entity_types ⇒ Array<String>
Entity types to detect.
Instance Attribute Details
#allowed_statistics ⇒ Array<Types::AllowedStatistics>
Configuration of statistics that are allowed to be run on columns that contain detected entities. When undefined, no statistics will be computed on columns that contain detected entities.
2540 2541 2542 2543 2544 2545 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2540 class EntityDetectorConfiguration < Struct.new( :entity_types, :allowed_statistics) SENSITIVE = [] include Aws::Structure end |
#entity_types ⇒ Array<String>
Entity types to detect. Can be any of the following:
-
USA_SSN
-
EMAIL
-
USA_ITIN
-
USA_PASSPORT_NUMBER
-
PHONE_NUMBER
-
USA_DRIVING_LICENSE
-
BANK_ACCOUNT
-
CREDIT_CARD
-
IP_ADDRESS
-
MAC_ADDRESS
-
USA_DEA_NUMBER
-
USA_HCPCS_CODE
-
USA_NATIONAL_PROVIDER_IDENTIFIER
-
USA_NATIONAL_DRUG_CODE
-
USA_HEALTH_INSURANCE_CLAIM_NUMBER
-
USA_MEDICARE_BENEFICIARY_IDENTIFIER
-
USA_CPT_CODE
-
PERSON_NAME
-
DATE
The Entity type group USA_ALL is also supported, and includes all of the above entity types except PERSON_NAME and DATE.
2540 2541 2542 2543 2544 2545 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2540 class EntityDetectorConfiguration < Struct.new( :entity_types, :allowed_statistics) SENSITIVE = [] include Aws::Structure end |