Class: Aws::GlueDataBrew::Types::ExcelOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::ExcelOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Note:
When making an API call, you may pass ExcelOptions data as a hash:
{
sheet_names: ["SheetName"],
sheet_indexes: [1],
header_row: false,
}
Represents a set of options that define how DataBrew will interpret a Microsoft Excel file when creating a dataset from that file.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#header_row ⇒ Boolean
A variable that specifies whether the first row in the file is parsed as the header.
-
#sheet_indexes ⇒ Array<Integer>
One or more sheet numbers in the Excel file that will be included in the dataset.
-
#sheet_names ⇒ Array<String>
One or more named sheets in the Excel file that will be included in the dataset.
Instance Attribute Details
#header_row ⇒ Boolean
A variable that specifies whether the first row in the file is parsed as the header. If this value is false, column names are auto-generated.
2577 2578 2579 2580 2581 2582 2583 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2577 class ExcelOptions < Struct.new( :sheet_names, :sheet_indexes, :header_row) SENSITIVE = [] include Aws::Structure end |
#sheet_indexes ⇒ Array<Integer>
One or more sheet numbers in the Excel file that will be included in the dataset.
2577 2578 2579 2580 2581 2582 2583 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2577 class ExcelOptions < Struct.new( :sheet_names, :sheet_indexes, :header_row) SENSITIVE = [] include Aws::Structure end |
#sheet_names ⇒ Array<String>
One or more named sheets in the Excel file that will be included in the dataset.
2577 2578 2579 2580 2581 2582 2583 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2577 class ExcelOptions < Struct.new( :sheet_names, :sheet_indexes, :header_row) SENSITIVE = [] include Aws::Structure end |