Class: Aws::GlueDataBrew::Types::FormatOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::FormatOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Note:
When making an API call, you may pass FormatOptions data as a hash:
{
json: {
multi_line: false,
},
excel: {
sheet_names: ["SheetName"],
sheet_indexes: [1],
header_row: false,
},
csv: {
delimiter: "Delimiter",
header_row: false,
},
}
Represents a set of options that define the structure of either comma-separated value (CSV), Excel, or JSON input.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#csv ⇒ Types::CsvOptions
Options that define how CSV input is to be interpreted by DataBrew.
-
#excel ⇒ Types::ExcelOptions
Options that define how Excel input is to be interpreted by DataBrew.
-
#json ⇒ Types::JsonOptions
Options that define how JSON input is to be interpreted by DataBrew.
Instance Attribute Details
#csv ⇒ Types::CsvOptions
Options that define how CSV input is to be interpreted by DataBrew.
2699 2700 2701 2702 2703 2704 2705 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2699 class FormatOptions < Struct.new( :json, :excel, :csv) SENSITIVE = [] include Aws::Structure end |
#excel ⇒ Types::ExcelOptions
Options that define how Excel input is to be interpreted by DataBrew.
2699 2700 2701 2702 2703 2704 2705 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2699 class FormatOptions < Struct.new( :json, :excel, :csv) SENSITIVE = [] include Aws::Structure end |
#json ⇒ Types::JsonOptions
Options that define how JSON input is to be interpreted by DataBrew.
2699 2700 2701 2702 2703 2704 2705 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2699 class FormatOptions < Struct.new( :json, :excel, :csv) SENSITIVE = [] include Aws::Structure end |