Class: Aws::GlueDataBrew::Types::Output
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::Output
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
When making an API call, you may pass Output data as a hash:
{
compression_format: "GZIP", # accepts GZIP, LZ4, SNAPPY, BZIP2, DEFLATE, LZO, BROTLI, ZSTD, ZLIB
format: "CSV", # accepts CSV, JSON, PARQUET, GLUEPARQUET, AVRO, ORC, XML, TABLEAUHYPER
partition_columns: ["ColumnName"],
location: { # required
bucket: "Bucket", # required
key: "Key",
bucket_owner: "BucketOwner",
},
overwrite: false,
format_options: {
csv: {
delimiter: "Delimiter",
},
},
}
Represents options that specify how and where in Amazon S3 DataBrew writes the output generated by recipe jobs or profile jobs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compression_format ⇒ String
The compression algorithm used to compress the output text of the job.
-
#format ⇒ String
The data format of the output of the job.
-
#format_options ⇒ Types::OutputFormatOptions
Represents options that define how DataBrew formats job output files.
-
#location ⇒ Types::S3Location
The location in Amazon S3 where the job writes its output.
-
#overwrite ⇒ Boolean
A value that, if true, means that any data in the location specified for output is overwritten with new output.
-
#partition_columns ⇒ Array<String>
The names of one or more partition columns for the output of the job.
Instance Attribute Details
#compression_format ⇒ String
The compression algorithm used to compress the output text of the job.
3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3628 class Output < Struct.new( :compression_format, :format, :partition_columns, :location, :overwrite, :format_options) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
The data format of the output of the job.
3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3628 class Output < Struct.new( :compression_format, :format, :partition_columns, :location, :overwrite, :format_options) SENSITIVE = [] include Aws::Structure end |
#format_options ⇒ Types::OutputFormatOptions
Represents options that define how DataBrew formats job output files.
3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3628 class Output < Struct.new( :compression_format, :format, :partition_columns, :location, :overwrite, :format_options) SENSITIVE = [] include Aws::Structure end |
#location ⇒ Types::S3Location
The location in Amazon S3 where the job writes its output.
3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3628 class Output < Struct.new( :compression_format, :format, :partition_columns, :location, :overwrite, :format_options) SENSITIVE = [] include Aws::Structure end |
#overwrite ⇒ Boolean
A value that, if true, means that any data in the location specified for output is overwritten with new output.
3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3628 class Output < Struct.new( :compression_format, :format, :partition_columns, :location, :overwrite, :format_options) SENSITIVE = [] include Aws::Structure end |
#partition_columns ⇒ Array<String>
The names of one or more partition columns for the output of the job.
3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3628 class Output < Struct.new( :compression_format, :format, :partition_columns, :location, :overwrite, :format_options) SENSITIVE = [] include Aws::Structure end |