Class: Aws::GlueDataBrew::Types::PathOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::PathOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
When making an API call, you may pass PathOptions data as a hash:
{
last_modified_date_condition: {
expression: "Expression", # required
values_map: { # required
"ValueReference" => "ConditionValue",
},
},
files_limit: {
max_files: 1, # required
ordered_by: "LAST_MODIFIED_DATE", # accepts LAST_MODIFIED_DATE
order: "DESCENDING", # accepts DESCENDING, ASCENDING
},
parameters: {
"PathParameterName" => {
name: "PathParameterName", # required
type: "Datetime", # required, accepts Datetime, Number, String
datetime_options: {
format: "DatetimeFormat", # required
timezone_offset: "TimezoneOffset",
locale_code: "LocaleCode",
},
create_column: false,
filter: {
expression: "Expression", # required
values_map: { # required
"ValueReference" => "ConditionValue",
},
},
},
},
}
Represents a set of options that define how DataBrew selects files for a given Amazon S3 path in a dataset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#files_limit ⇒ Types::FilesLimit
If provided, this structure imposes a limit on a number of files that should be selected.
-
#last_modified_date_condition ⇒ Types::FilterExpression
If provided, this structure defines a date range for matching Amazon S3 objects based on their LastModifiedDate attribute in Amazon S3.
-
#parameters ⇒ Hash<String,Types::DatasetParameter>
A structure that maps names of parameters used in the Amazon S3 path of a dataset to their definitions.
Instance Attribute Details
#files_limit ⇒ Types::FilesLimit
If provided, this structure imposes a limit on a number of files that should be selected.
3719 3720 3721 3722 3723 3724 3725 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3719 class PathOptions < Struct.new( :last_modified_date_condition, :files_limit, :parameters) SENSITIVE = [] include Aws::Structure end |
#last_modified_date_condition ⇒ Types::FilterExpression
If provided, this structure defines a date range for matching Amazon S3 objects based on their LastModifiedDate attribute in Amazon S3.
3719 3720 3721 3722 3723 3724 3725 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3719 class PathOptions < Struct.new( :last_modified_date_condition, :files_limit, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::DatasetParameter>
A structure that maps names of parameters used in the Amazon S3 path of a dataset to their definitions.
3719 3720 3721 3722 3723 3724 3725 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3719 class PathOptions < Struct.new( :last_modified_date_condition, :files_limit, :parameters) SENSITIVE = [] include Aws::Structure end |