Class: Aws::GlueDataBrew::Types::Project
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::Project
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Represents all of the attributes of a DataBrew project.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the Amazon Web Services account that owns the project.
-
#create_date ⇒ Time
The date and time that the project was created.
-
#created_by ⇒ String
The Amazon Resource Name (ARN) of the user who crated the project.
-
#dataset_name ⇒ String
The dataset that the project is to act upon.
-
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last modified the project.
-
#last_modified_date ⇒ Time
The last modification date and time for the project.
-
#name ⇒ String
The unique name of a project.
-
#open_date ⇒ Time
The date and time when the project was opened.
-
#opened_by ⇒ String
The Amazon Resource Name (ARN) of the user that opened the project for use.
-
#recipe_name ⇒ String
The name of a recipe that will be developed during a project session.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) for the project.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role that will be assumed for this project.
-
#sample ⇒ Types::Sample
The sample size and sampling type to apply to the data.
-
#tags ⇒ Hash<String,String>
Metadata tags that have been applied to the project.
Instance Attribute Details
#account_id ⇒ String
The ID of the Amazon Web Services account that owns the project.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |
#create_date ⇒ Time
The date and time that the project was created.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The Amazon Resource Name (ARN) of the user who crated the project.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |
#dataset_name ⇒ String
The dataset that the project is to act upon.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last modified the project.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The last modification date and time for the project.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique name of a project.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |
#open_date ⇒ Time
The date and time when the project was opened.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |
#opened_by ⇒ String
The Amazon Resource Name (ARN) of the user that opened the project for use.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |
#recipe_name ⇒ String
The name of a recipe that will be developed during a project session.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) for the project.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role that will be assumed for this project.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |
#sample ⇒ Types::Sample
The sample size and sampling type to apply to the data. If this parameter isn't specified, then the sample consists of the first 500 rows from the dataset.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata tags that have been applied to the project.
3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 3887 class Project < Struct.new( :account_id, :create_date, :created_by, :dataset_name, :last_modified_date, :last_modified_by, :name, :recipe_name, :resource_arn, :sample, :tags, :role_arn, :opened_by, :open_date) SENSITIVE = [] include Aws::Structure end |