Class: Aws::GlueDataBrew::Types::Recipe
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::Recipe
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Represents one or more actions to be performed on a DataBrew dataset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_date ⇒ Time
The date and time that the recipe was created.
-
#created_by ⇒ String
The Amazon Resource Name (ARN) of the user who created the recipe.
-
#description ⇒ String
The description of the recipe.
-
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last modified the recipe.
-
#last_modified_date ⇒ Time
The last modification date and time of the recipe.
-
#name ⇒ String
The unique name for the recipe.
-
#project_name ⇒ String
The name of the project that the recipe is associated with.
-
#published_by ⇒ String
The Amazon Resource Name (ARN) of the user who published the recipe.
-
#published_date ⇒ Time
The date and time when the recipe was published.
-
#recipe_version ⇒ String
The identifier for the version for the recipe.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) for the recipe.
-
#steps ⇒ Array<Types::RecipeStep>
A list of steps that are defined by the recipe.
-
#tags ⇒ Hash<String,String>
Metadata tags that have been applied to the recipe.
Instance Attribute Details
#create_date ⇒ Time
The date and time that the recipe was created.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4012 class Recipe < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :resource_arn, :steps, :tags, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The Amazon Resource Name (ARN) of the user who created the recipe.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4012 class Recipe < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :resource_arn, :steps, :tags, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the recipe.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4012 class Recipe < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :resource_arn, :steps, :tags, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last modified the recipe.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4012 class Recipe < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :resource_arn, :steps, :tags, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The last modification date and time of the recipe.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4012 class Recipe < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :resource_arn, :steps, :tags, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique name for the recipe.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4012 class Recipe < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :resource_arn, :steps, :tags, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
The name of the project that the recipe is associated with.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4012 class Recipe < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :resource_arn, :steps, :tags, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#published_by ⇒ String
The Amazon Resource Name (ARN) of the user who published the recipe.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4012 class Recipe < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :resource_arn, :steps, :tags, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#published_date ⇒ Time
The date and time when the recipe was published.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4012 class Recipe < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :resource_arn, :steps, :tags, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#recipe_version ⇒ String
The identifier for the version for the recipe. Must be one of the following:
-
Numeric version (`X.Y`) - `X` and `Y` stand for major and minor version numbers. The maximum length of each is 6 digits, and neither can be negative values. Both `X` and `Y` are required, and “0.0” isn't a valid version.
-
`LATEST_WORKING` - the most recent valid version being developed in a DataBrew project.
-
`LATEST_PUBLISHED` - the most recent published version.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4012 class Recipe < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :resource_arn, :steps, :tags, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) for the recipe.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4012 class Recipe < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :resource_arn, :steps, :tags, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#steps ⇒ Array<Types::RecipeStep>
A list of steps that are defined by the recipe.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4012 class Recipe < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :resource_arn, :steps, :tags, :recipe_version) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata tags that have been applied to the recipe.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4012 class Recipe < Struct.new( :created_by, :create_date, :last_modified_by, :last_modified_date, :project_name, :published_by, :published_date, :description, :name, :resource_arn, :steps, :tags, :recipe_version) SENSITIVE = [] include Aws::Structure end |