Class: Aws::GlueDataBrew::Types::RecipeStep

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gluedatabrew/types.rb

Overview

Note:

When making an API call, you may pass RecipeStep data as a hash:

{
  action: { # required
    operation: "Operation", # required
    parameters: {
      "ParameterName" => "ParameterValue",
    },
  },
  condition_expressions: [
    {
      condition: "Condition", # required
      value: "ConditionValue",
      target_column: "TargetColumn", # required
    },
  ],
}

Represents a single step from a DataBrew recipe to be performed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionTypes::RecipeAction

The particular action to be performed in the recipe step.

Returns:



4130
4131
4132
4133
4134
4135
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4130

class RecipeStep < Struct.new(
  :action,
  :condition_expressions)
  SENSITIVE = []
  include Aws::Structure
end

#condition_expressionsArray<Types::ConditionExpression>

One or more conditions that must be met for the recipe step to succeed.

<note markdown=“1”> All of the conditions in the array must be met. In other words, all of the conditions must be combined using a logical AND operation.

</note>

Returns:



4130
4131
4132
4133
4134
4135
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4130

class RecipeStep < Struct.new(
  :action,
  :condition_expressions)
  SENSITIVE = []
  include Aws::Structure
end