Class: Aws::GlueDataBrew::Types::Rule
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::Rule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
When making an API call, you may pass Rule data as a hash:
{
name: "RuleName", # required
disabled: false,
check_expression: "Expression", # required
substitution_map: {
"ValueReference" => "ConditionValue",
},
threshold: {
value: 1.0, # required
type: "GREATER_THAN_OR_EQUAL", # accepts GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, GREATER_THAN, LESS_THAN
unit: "COUNT", # accepts COUNT, PERCENTAGE
},
column_selectors: [
{
regex: "ColumnName",
name: "ColumnName",
},
],
}
Represents a single data quality requirement that should be validated in the scope of this dataset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#check_expression ⇒ String
The expression which includes column references, condition names followed by variable references, possibly grouped and combined with other conditions.
-
#column_selectors ⇒ Array<Types::ColumnSelector>
List of column selectors.
-
#disabled ⇒ Boolean
A value that specifies whether the rule is disabled.
-
#name ⇒ String
The name of the rule.
-
#substitution_map ⇒ Hash<String,String>
The map of substitution variable names to their values used in a check expression.
-
#threshold ⇒ Types::Threshold
The threshold used with a non-aggregate check expression.
Instance Attribute Details
#check_expression ⇒ String
The expression which includes column references, condition names followed by variable references, possibly grouped and combined with other conditions. For example, `(:col1 starts_with :prefix1 or :col1 starts_with :prefix2) and (:col1 ends_with :suffix1 or :col1 ends_with :suffix2)`. Column and value references are substitution variables that should start with the ':' symbol. Depending on the context, substitution variables' values can be either an actual value or a column name. These values are defined in the SubstitutionMap. If a CheckExpression starts with a column reference, then ColumnSelectors in the rule should be null. If ColumnSelectors has been defined, then there should be no columnn reference in the left side of a condition, for example, `is_between :val1 and :val2`.
For more information, see [Available checks]
[1]: docs.aws.amazon.com/databrew/latest/dg/profile.data-quality-available-checks.html
4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4256 class Rule < Struct.new( :name, :disabled, :check_expression, :substitution_map, :threshold, :column_selectors) SENSITIVE = [] include Aws::Structure end |
#column_selectors ⇒ Array<Types::ColumnSelector>
List of column selectors. Selectors can be used to select columns using a name or regular expression from the dataset. Rule will be applied to selected columns.
4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4256 class Rule < Struct.new( :name, :disabled, :check_expression, :substitution_map, :threshold, :column_selectors) SENSITIVE = [] include Aws::Structure end |
#disabled ⇒ Boolean
A value that specifies whether the rule is disabled. Once a rule is disabled, a profile job will not validate it during a job run. Default value is false.
4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4256 class Rule < Struct.new( :name, :disabled, :check_expression, :substitution_map, :threshold, :column_selectors) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule.
4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4256 class Rule < Struct.new( :name, :disabled, :check_expression, :substitution_map, :threshold, :column_selectors) SENSITIVE = [] include Aws::Structure end |
#substitution_map ⇒ Hash<String,String>
The map of substitution variable names to their values used in a check expression. Variable names should start with a ':' (colon). Variable values can either be actual values or column names. To differentiate between the two, column names should be enclosed in backticks, for example, “ “:col1”: “`Column A`”. “
4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4256 class Rule < Struct.new( :name, :disabled, :check_expression, :substitution_map, :threshold, :column_selectors) SENSITIVE = [] include Aws::Structure end |
#threshold ⇒ Types::Threshold
The threshold used with a non-aggregate check expression. Non-aggregate check expressions will be applied to each row in a specific column, and the threshold will be used to determine whether the validation succeeds.
4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4256 class Rule < Struct.new( :name, :disabled, :check_expression, :substitution_map, :threshold, :column_selectors) SENSITIVE = [] include Aws::Structure end |