Class: Aws::GlueDataBrew::Types::S3Location
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::S3Location
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Note:
When making an API call, you may pass S3Location data as a hash:
{
bucket: "Bucket", # required
key: "Key",
bucket_owner: "BucketOwner",
}
Represents an Amazon S3 location (bucket name, bucket owner, and object key) where DataBrew can read input data, or write output from a job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The Amazon S3 bucket name.
-
#bucket_owner ⇒ String
The Amazon Web Services account ID of the bucket owner.
-
#key ⇒ String
The unique name of the object in the bucket.
Instance Attribute Details
#bucket ⇒ String
The Amazon S3 bucket name.
4360 4361 4362 4363 4364 4365 4366 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4360 class S3Location < Struct.new( :bucket, :key, :bucket_owner) SENSITIVE = [] include Aws::Structure end |
#bucket_owner ⇒ String
The Amazon Web Services account ID of the bucket owner.
4360 4361 4362 4363 4364 4365 4366 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4360 class S3Location < Struct.new( :bucket, :key, :bucket_owner) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The unique name of the object in the bucket.
4360 4361 4362 4363 4364 4365 4366 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4360 class S3Location < Struct.new( :bucket, :key, :bucket_owner) SENSITIVE = [] include Aws::Structure end |