Class: Aws::GlueDataBrew::Types::SendProjectSessionActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::SendProjectSessionActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
When making an API call, you may pass SendProjectSessionActionRequest data as a hash:
{
preview: false,
name: "ProjectName", # required
recipe_step: {
action: { # required
operation: "Operation", # required
parameters: {
"ParameterName" => "ParameterValue",
},
},
condition_expressions: [
{
condition: "Condition", # required
value: "ConditionValue",
target_column: "TargetColumn", # required
},
],
},
step_index: 1,
client_session_id: "ClientSessionId",
view_frame: {
start_column_index: 1, # required
column_range: 1,
hidden_columns: ["ColumnName"],
start_row_index: 1,
row_range: 1,
analytics: "ENABLE", # accepts ENABLE, DISABLE
},
}
Constant Summary collapse
- SENSITIVE =
[:client_session_id]
Instance Attribute Summary collapse
-
#client_session_id ⇒ String
A unique identifier for an interactive session that's currently open and ready for work.
-
#name ⇒ String
The name of the project to apply the action to.
-
#preview ⇒ Boolean
If true, the result of the recipe step will be returned, but not applied.
-
#recipe_step ⇒ Types::RecipeStep
Represents a single step from a DataBrew recipe to be performed.
-
#step_index ⇒ Integer
The index from which to preview a step.
-
#view_frame ⇒ Types::ViewFrame
Represents the data being transformed during an action.
Instance Attribute Details
#client_session_id ⇒ String
A unique identifier for an interactive session that's currently open and ready for work. The action will be performed on this session.
4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4552 class SendProjectSessionActionRequest < Struct.new( :preview, :name, :recipe_step, :step_index, :client_session_id, :view_frame) SENSITIVE = [:client_session_id] include Aws::Structure end |
#name ⇒ String
The name of the project to apply the action to.
4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4552 class SendProjectSessionActionRequest < Struct.new( :preview, :name, :recipe_step, :step_index, :client_session_id, :view_frame) SENSITIVE = [:client_session_id] include Aws::Structure end |
#preview ⇒ Boolean
If true, the result of the recipe step will be returned, but not applied.
4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4552 class SendProjectSessionActionRequest < Struct.new( :preview, :name, :recipe_step, :step_index, :client_session_id, :view_frame) SENSITIVE = [:client_session_id] include Aws::Structure end |
#recipe_step ⇒ Types::RecipeStep
Represents a single step from a DataBrew recipe to be performed.
4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4552 class SendProjectSessionActionRequest < Struct.new( :preview, :name, :recipe_step, :step_index, :client_session_id, :view_frame) SENSITIVE = [:client_session_id] include Aws::Structure end |
#step_index ⇒ Integer
The index from which to preview a step. This index is used to preview the result of steps that have already been applied, so that the resulting view frame is from earlier in the view frame stack.
4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4552 class SendProjectSessionActionRequest < Struct.new( :preview, :name, :recipe_step, :step_index, :client_session_id, :view_frame) SENSITIVE = [:client_session_id] include Aws::Structure end |
#view_frame ⇒ Types::ViewFrame
Represents the data being transformed during an action.
4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 4552 class SendProjectSessionActionRequest < Struct.new( :preview, :name, :recipe_step, :step_index, :client_session_id, :view_frame) SENSITIVE = [:client_session_id] include Aws::Structure end |