Class: Aws::GlueDataBrew::Types::UpdateProfileJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gluedatabrew/types.rb

Overview

Note:

When making an API call, you may pass UpdateProfileJobRequest data as a hash:

{
  configuration: {
    dataset_statistics_configuration: {
      included_statistics: ["Statistic"],
      overrides: [
        {
          statistic: "Statistic", # required
          parameters: { # required
            "ParameterName" => "ParameterValue",
          },
        },
      ],
    },
    profile_columns: [
      {
        regex: "ColumnName",
        name: "ColumnName",
      },
    ],
    column_statistics_configurations: [
      {
        selectors: [
          {
            regex: "ColumnName",
            name: "ColumnName",
          },
        ],
        statistics: { # required
          included_statistics: ["Statistic"],
          overrides: [
            {
              statistic: "Statistic", # required
              parameters: { # required
                "ParameterName" => "ParameterValue",
              },
            },
          ],
        },
      },
    ],
    entity_detector_configuration: {
      entity_types: ["EntityType"], # required
      allowed_statistics: [
        {
          statistics: ["Statistic"], # required
        },
      ],
    },
  },
  encryption_key_arn: "EncryptionKeyArn",
  encryption_mode: "SSE-KMS", # accepts SSE-KMS, SSE-S3
  name: "JobName", # required
  log_subscription: "ENABLE", # accepts ENABLE, DISABLE
  max_capacity: 1,
  max_retries: 1,
  output_location: { # required
    bucket: "Bucket", # required
    key: "Key",
    bucket_owner: "BucketOwner",
  },
  validation_configurations: [
    {
      ruleset_arn: "Arn", # required
      validation_mode: "CHECK_ALL", # accepts CHECK_ALL
    },
  ],
  role_arn: "Arn", # required
  timeout: 1,
  job_sample: {
    mode: "FULL_DATASET", # accepts FULL_DATASET, CUSTOM_ROWS
    size: 1,
  },
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationTypes::ProfileConfiguration

Configuration for profile jobs. Used to select columns, do evaluations, and override default parameters of evaluations. When configuration is null, the profile job will run with default settings.



5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5154

class UpdateProfileJobRequest < Struct.new(
  :configuration,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :output_location,
  :validation_configurations,
  :role_arn,
  :timeout,
  :job_sample)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_key_arnString

The Amazon Resource Name (ARN) of an encryption key that is used to protect the job.

Returns:

  • (String)


5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5154

class UpdateProfileJobRequest < Struct.new(
  :configuration,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :output_location,
  :validation_configurations,
  :role_arn,
  :timeout,
  :job_sample)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_modeString

The encryption mode for the job, which can be one of the following:

  • `SSE-KMS` - Server-side encryption with keys managed by KMS.

  • `SSE-S3` - Server-side encryption with keys managed by Amazon S3.

Returns:

  • (String)


5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5154

class UpdateProfileJobRequest < Struct.new(
  :configuration,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :output_location,
  :validation_configurations,
  :role_arn,
  :timeout,
  :job_sample)
  SENSITIVE = []
  include Aws::Structure
end

#job_sampleTypes::JobSample

Sample configuration for Profile Jobs only. Determines the number of rows on which the Profile job will be executed. If a JobSample value is not provided for profile jobs, the default value will be used. The default value is CUSTOM_ROWS for the mode parameter and 20000 for the size parameter.

Returns:



5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5154

class UpdateProfileJobRequest < Struct.new(
  :configuration,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :output_location,
  :validation_configurations,
  :role_arn,
  :timeout,
  :job_sample)
  SENSITIVE = []
  include Aws::Structure
end

#log_subscriptionString

Enables or disables Amazon CloudWatch logging for the job. If logging is enabled, CloudWatch writes one log stream for each job run.

Returns:

  • (String)


5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5154

class UpdateProfileJobRequest < Struct.new(
  :configuration,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :output_location,
  :validation_configurations,
  :role_arn,
  :timeout,
  :job_sample)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacityInteger

The maximum number of compute nodes that DataBrew can use when the job processes data.

Returns:

  • (Integer)


5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5154

class UpdateProfileJobRequest < Struct.new(
  :configuration,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :output_location,
  :validation_configurations,
  :role_arn,
  :timeout,
  :job_sample)
  SENSITIVE = []
  include Aws::Structure
end

#max_retriesInteger

The maximum number of times to retry the job after a job run fails.

Returns:

  • (Integer)


5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5154

class UpdateProfileJobRequest < Struct.new(
  :configuration,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :output_location,
  :validation_configurations,
  :role_arn,
  :timeout,
  :job_sample)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the job to be updated.

Returns:

  • (String)


5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5154

class UpdateProfileJobRequest < Struct.new(
  :configuration,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :output_location,
  :validation_configurations,
  :role_arn,
  :timeout,
  :job_sample)
  SENSITIVE = []
  include Aws::Structure
end

#output_locationTypes::S3Location

Represents an Amazon S3 location (bucket name, bucket owner, and object key) where DataBrew can read input data, or write output from a job.

Returns:



5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5154

class UpdateProfileJobRequest < Struct.new(
  :configuration,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :output_location,
  :validation_configurations,
  :role_arn,
  :timeout,
  :job_sample)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role to be assumed when DataBrew runs the job.

Returns:

  • (String)


5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5154

class UpdateProfileJobRequest < Struct.new(
  :configuration,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :output_location,
  :validation_configurations,
  :role_arn,
  :timeout,
  :job_sample)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The job's timeout in minutes. A job that attempts to run longer than this timeout period ends with a status of `TIMEOUT`.

Returns:

  • (Integer)


5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5154

class UpdateProfileJobRequest < Struct.new(
  :configuration,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :output_location,
  :validation_configurations,
  :role_arn,
  :timeout,
  :job_sample)
  SENSITIVE = []
  include Aws::Structure
end

#validation_configurationsArray<Types::ValidationConfiguration>

List of validation configurations that are applied to the profile job.

Returns:



5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5154

class UpdateProfileJobRequest < Struct.new(
  :configuration,
  :encryption_key_arn,
  :encryption_mode,
  :name,
  :log_subscription,
  :max_capacity,
  :max_retries,
  :output_location,
  :validation_configurations,
  :role_arn,
  :timeout,
  :job_sample)
  SENSITIVE = []
  include Aws::Structure
end