Class: Aws::GlueDataBrew::Types::UpdateProjectResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::UpdateProjectResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_modified_date ⇒ Time
The date and time that the project was last modified.
-
#name ⇒ String
The name of the project that you updated.
Instance Attribute Details
#last_modified_date ⇒ Time
The date and time that the project was last modified.
5238 5239 5240 5241 5242 5243 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5238 class UpdateProjectResponse < Struct.new( :last_modified_date, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the project that you updated.
5238 5239 5240 5241 5242 5243 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5238 class UpdateProjectResponse < Struct.new( :last_modified_date, :name) SENSITIVE = [] include Aws::Structure end |