Class: Aws::GlueDataBrew::Types::UpdateScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::UpdateScheduleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Note:
When making an API call, you may pass UpdateScheduleRequest data as a hash:
{
job_names: ["JobName"],
cron_expression: "CronExpression", # required
name: "ScheduleName", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cron_expression ⇒ String
The date or dates and time or times when the jobs are to be run.
-
#job_names ⇒ Array<String>
The name or names of one or more jobs to be run for this schedule.
-
#name ⇒ String
The name of the schedule to update.
Instance Attribute Details
#cron_expression ⇒ String
The date or dates and time or times when the jobs are to be run. For more information, see [Cron expressions] in the *Glue DataBrew Developer Guide*.
5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5546 class UpdateScheduleRequest < Struct.new( :job_names, :cron_expression, :name) SENSITIVE = [] include Aws::Structure end |
#job_names ⇒ Array<String>
The name or names of one or more jobs to be run for this schedule.
5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5546 class UpdateScheduleRequest < Struct.new( :job_names, :cron_expression, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the schedule to update.
5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5546 class UpdateScheduleRequest < Struct.new( :job_names, :cron_expression, :name) SENSITIVE = [] include Aws::Structure end |