Class: Aws::GlueDataBrew::Types::ValidationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::ValidationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
When making an API call, you may pass ValidationConfiguration data as a hash:
{
ruleset_arn: "Arn", # required
validation_mode: "CHECK_ALL", # accepts CHECK_ALL
}
Configuration for data quality validation. Used to select the Rulesets and Validation Mode to be used in the profile job. When ValidationConfiguration is null, the profile job will run without data quality validation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ruleset_arn ⇒ String
The Amazon Resource Name (ARN) for the ruleset to be validated in the profile job.
-
#validation_mode ⇒ String
Mode of data quality validation.
Instance Attribute Details
#ruleset_arn ⇒ String
The Amazon Resource Name (ARN) for the ruleset to be validated in the profile job. The TargetArn of the selected ruleset should be the same as the Amazon Resource Name (ARN) of the dataset that is associated with the profile job.
5593 5594 5595 5596 5597 5598 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5593 class ValidationConfiguration < Struct.new( :ruleset_arn, :validation_mode) SENSITIVE = [] include Aws::Structure end |
#validation_mode ⇒ String
Mode of data quality validation. Default mode is “CHECK_ALL” which verifies all rules defined in the selected ruleset.
5593 5594 5595 5596 5597 5598 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5593 class ValidationConfiguration < Struct.new( :ruleset_arn, :validation_mode) SENSITIVE = [] include Aws::Structure end |