Class: Aws::GlueDataBrew::Types::ViewFrame
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::ViewFrame
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
When making an API call, you may pass ViewFrame data as a hash:
{
start_column_index: 1, # required
column_range: 1,
hidden_columns: ["ColumnName"],
start_row_index: 1,
row_range: 1,
analytics: "ENABLE", # accepts ENABLE, DISABLE
}
Represents the data being transformed during an action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analytics ⇒ String
Controls if analytics computation is enabled or disabled.
-
#column_range ⇒ Integer
The number of columns to include in the view frame, beginning with the `StartColumnIndex` value and ignoring any columns in the `HiddenColumns` list.
-
#hidden_columns ⇒ Array<String>
A list of columns to hide in the view frame.
-
#row_range ⇒ Integer
The number of rows to include in the view frame, beginning with the `StartRowIndex` value.
-
#start_column_index ⇒ Integer
The starting index for the range of columns to return in the view frame.
-
#start_row_index ⇒ Integer
The starting index for the range of rows to return in the view frame.
Instance Attribute Details
#analytics ⇒ String
Controls if analytics computation is enabled or disabled. Enabled by default.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5669 class ViewFrame < Struct.new( :start_column_index, :column_range, :hidden_columns, :start_row_index, :row_range, :analytics) SENSITIVE = [] include Aws::Structure end |
#column_range ⇒ Integer
The number of columns to include in the view frame, beginning with the `StartColumnIndex` value and ignoring any columns in the `HiddenColumns` list.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5669 class ViewFrame < Struct.new( :start_column_index, :column_range, :hidden_columns, :start_row_index, :row_range, :analytics) SENSITIVE = [] include Aws::Structure end |
#hidden_columns ⇒ Array<String>
A list of columns to hide in the view frame.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5669 class ViewFrame < Struct.new( :start_column_index, :column_range, :hidden_columns, :start_row_index, :row_range, :analytics) SENSITIVE = [] include Aws::Structure end |
#row_range ⇒ Integer
The number of rows to include in the view frame, beginning with the `StartRowIndex` value.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5669 class ViewFrame < Struct.new( :start_column_index, :column_range, :hidden_columns, :start_row_index, :row_range, :analytics) SENSITIVE = [] include Aws::Structure end |
#start_column_index ⇒ Integer
The starting index for the range of columns to return in the view frame.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5669 class ViewFrame < Struct.new( :start_column_index, :column_range, :hidden_columns, :start_row_index, :row_range, :analytics) SENSITIVE = [] include Aws::Structure end |
#start_row_index ⇒ Integer
The starting index for the range of rows to return in the view frame.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 5669 class ViewFrame < Struct.new( :start_column_index, :column_range, :hidden_columns, :start_row_index, :row_range, :analytics) SENSITIVE = [] include Aws::Structure end |