Class: Aws::GlueDataBrew::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::GlueDataBrew::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-gluedatabrew/client.rb
Overview
An API client for GlueDataBrew. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::GlueDataBrew::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_delete_recipe_version(params = {}) ⇒ Types::BatchDeleteRecipeVersionResponse
Deletes one or more versions of a recipe at a time.
-
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new DataBrew dataset.
-
#create_profile_job(params = {}) ⇒ Types::CreateProfileJobResponse
Creates a new job to analyze a dataset and create its data profile.
-
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a new DataBrew project.
-
#create_recipe(params = {}) ⇒ Types::CreateRecipeResponse
Creates a new DataBrew recipe.
-
#create_recipe_job(params = {}) ⇒ Types::CreateRecipeJobResponse
Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe.
-
#create_ruleset(params = {}) ⇒ Types::CreateRulesetResponse
Creates a new ruleset that can be used in a profile job to validate the data quality of a dataset.
-
#create_schedule(params = {}) ⇒ Types::CreateScheduleResponse
Creates a new schedule for one or more DataBrew jobs.
-
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a dataset from DataBrew.
-
#delete_job(params = {}) ⇒ Types::DeleteJobResponse
Deletes the specified DataBrew job.
-
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes an existing DataBrew project.
-
#delete_recipe_version(params = {}) ⇒ Types::DeleteRecipeVersionResponse
Deletes a single version of a DataBrew recipe.
-
#delete_ruleset(params = {}) ⇒ Types::DeleteRulesetResponse
Deletes a ruleset.
-
#delete_schedule(params = {}) ⇒ Types::DeleteScheduleResponse
Deletes the specified DataBrew schedule.
-
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns the definition of a specific DataBrew dataset.
-
#describe_job(params = {}) ⇒ Types::DescribeJobResponse
Returns the definition of a specific DataBrew job.
-
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Represents one run of a DataBrew job.
-
#describe_project(params = {}) ⇒ Types::DescribeProjectResponse
Returns the definition of a specific DataBrew project.
-
#describe_recipe(params = {}) ⇒ Types::DescribeRecipeResponse
Returns the definition of a specific DataBrew recipe corresponding to a particular version.
-
#describe_ruleset(params = {}) ⇒ Types::DescribeRulesetResponse
Retrieves detailed information about the ruleset.
-
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Returns the definition of a specific DataBrew schedule.
-
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the DataBrew datasets.
-
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists all of the previous runs of a particular DataBrew job.
-
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists all of the DataBrew jobs that are defined.
-
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Lists all of the DataBrew projects that are defined.
-
#list_recipe_versions(params = {}) ⇒ Types::ListRecipeVersionsResponse
Lists the versions of a particular DataBrew recipe, except for ‘LATEST_WORKING`.
-
#list_recipes(params = {}) ⇒ Types::ListRecipesResponse
Lists all of the DataBrew recipes that are defined.
-
#list_rulesets(params = {}) ⇒ Types::ListRulesetsResponse
List all rulesets available in the current account or rulesets associated with a specific resource (dataset).
-
#list_schedules(params = {}) ⇒ Types::ListSchedulesResponse
Lists the DataBrew schedules that are defined.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags for a DataBrew resource.
-
#publish_recipe(params = {}) ⇒ Types::PublishRecipeResponse
Publishes a new version of a DataBrew recipe.
-
#send_project_session_action(params = {}) ⇒ Types::SendProjectSessionActionResponse
Performs a recipe step within an interactive DataBrew session that’s currently open.
-
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Runs a DataBrew job.
-
#start_project_session(params = {}) ⇒ Types::StartProjectSessionResponse
Creates an interactive session, enabling you to manipulate data in a DataBrew project.
-
#stop_job_run(params = {}) ⇒ Types::StopJobRunResponse
Stops a particular run of a job.
-
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule.
-
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a DataBrew resource.
-
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Modifies the definition of an existing DataBrew dataset.
-
#update_profile_job(params = {}) ⇒ Types::UpdateProfileJobResponse
Modifies the definition of an existing profile job.
-
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Modifies the definition of an existing DataBrew project.
-
#update_recipe(params = {}) ⇒ Types::UpdateRecipeResponse
Modifies the definition of the ‘LATEST_WORKING` version of a DataBrew recipe.
-
#update_recipe_job(params = {}) ⇒ Types::UpdateRecipeJobResponse
Modifies the definition of an existing DataBrew recipe job.
-
#update_ruleset(params = {}) ⇒ Types::UpdateRulesetResponse
Updates specified ruleset.
-
#update_schedule(params = {}) ⇒ Types::UpdateScheduleResponse
Modifies the definition of an existing DataBrew schedule.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3461 3462 3463 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3461 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3464 3465 3466 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3464 def errors_module Errors end |
Instance Method Details
#batch_delete_recipe_version(params = {}) ⇒ Types::BatchDeleteRecipeVersionResponse
Deletes one or more versions of a recipe at a time.
The entire request will be rejected if:
-
The recipe does not exist.
-
There is an invalid version identifier in the list of versions.
-
The version list is empty.
-
The version list size exceeds 50.
-
The version list contains duplicate entries.
The request will complete successfully, but with partial failures, if:
-
A version does not exist.
-
A version is being used by a job.
-
You specify ‘LATEST_WORKING`, but it’s being used by a project.
-
The version fails to be deleted.
The ‘LATEST_WORKING` version will only be deleted if the recipe has no other versions. If you try to delete `LATEST_WORKING` while other versions exist (or if they can’t be deleted), then ‘LATEST_WORKING` will be listed as partial failure in the response.
538 539 540 541 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 538 def batch_delete_recipe_version(params = {}, = {}) req = build_request(:batch_delete_recipe_version, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3434 3435 3436 3437 3438 3439 3440 3441 3442 3443 3444 3445 3446 3447 3448 3449 3450 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3434 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::GlueDataBrew') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-gluedatabrew' context[:gem_version] = '1.70.0' Seahorse::Client::Request.new(handlers, context) end |
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new DataBrew dataset.
665 666 667 668 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 665 def create_dataset(params = {}, = {}) req = build_request(:create_dataset, params) req.send_request() end |
#create_profile_job(params = {}) ⇒ Types::CreateProfileJobResponse
Creates a new job to analyze a dataset and create its data profile.
824 825 826 827 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 824 def create_profile_job(params = {}, = {}) req = build_request(:create_profile_job, params) req.send_request() end |
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a new DataBrew project.
880 881 882 883 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 880 def create_project(params = {}, = {}) req = build_request(:create_project, params) req.send_request() end |
#create_recipe(params = {}) ⇒ Types::CreateRecipeResponse
Creates a new DataBrew recipe.
941 942 943 944 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 941 def create_recipe(params = {}, = {}) req = build_request(:create_recipe, params) req.send_request() end |
#create_recipe_job(params = {}) ⇒ Types::CreateRecipeJobResponse
Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe
1097 1098 1099 1100 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1097 def create_recipe_job(params = {}, = {}) req = build_request(:create_recipe_job, params) req.send_request() end |
#create_ruleset(params = {}) ⇒ Types::CreateRulesetResponse
Creates a new ruleset that can be used in a profile job to validate the data quality of a dataset.
1167 1168 1169 1170 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1167 def create_ruleset(params = {}, = {}) req = build_request(:create_ruleset, params) req.send_request() end |
#create_schedule(params = {}) ⇒ Types::CreateScheduleResponse
Creates a new schedule for one or more DataBrew jobs. Jobs can be run at a specific date and time, or at regular intervals.
1217 1218 1219 1220 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1217 def create_schedule(params = {}, = {}) req = build_request(:create_schedule, params) req.send_request() end |
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a dataset from DataBrew.
1245 1246 1247 1248 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1245 def delete_dataset(params = {}, = {}) req = build_request(:delete_dataset, params) req.send_request() end |
#delete_job(params = {}) ⇒ Types::DeleteJobResponse
Deletes the specified DataBrew job.
1273 1274 1275 1276 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1273 def delete_job(params = {}, = {}) req = build_request(:delete_job, params) req.send_request() end |
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes an existing DataBrew project.
1301 1302 1303 1304 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1301 def delete_project(params = {}, = {}) req = build_request(:delete_project, params) req.send_request() end |
#delete_recipe_version(params = {}) ⇒ Types::DeleteRecipeVersionResponse
Deletes a single version of a DataBrew recipe.
1337 1338 1339 1340 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1337 def delete_recipe_version(params = {}, = {}) req = build_request(:delete_recipe_version, params) req.send_request() end |
#delete_ruleset(params = {}) ⇒ Types::DeleteRulesetResponse
Deletes a ruleset.
1365 1366 1367 1368 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1365 def delete_ruleset(params = {}, = {}) req = build_request(:delete_ruleset, params) req.send_request() end |
#delete_schedule(params = {}) ⇒ Types::DeleteScheduleResponse
Deletes the specified DataBrew schedule.
1393 1394 1395 1396 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1393 def delete_schedule(params = {}, = {}) req = build_request(:delete_schedule, params) req.send_request() end |
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns the definition of a specific DataBrew dataset.
1481 1482 1483 1484 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1481 def describe_dataset(params = {}, = {}) req = build_request(:describe_dataset, params) req.send_request() end |
#describe_job(params = {}) ⇒ Types::DescribeJobResponse
Returns the definition of a specific DataBrew job.
1610 1611 1612 1613 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1610 def describe_job(params = {}, = {}) req = build_request(:describe_job, params) req.send_request() end |
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Represents one run of a DataBrew job.
1732 1733 1734 1735 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1732 def describe_job_run(params = {}, = {}) req = build_request(:describe_job_run, params) req.send_request() end |
#describe_project(params = {}) ⇒ Types::DescribeProjectResponse
Returns the definition of a specific DataBrew project.
1788 1789 1790 1791 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1788 def describe_project(params = {}, = {}) req = build_request(:describe_project, params) req.send_request() end |
#describe_recipe(params = {}) ⇒ Types::DescribeRecipeResponse
Returns the definition of a specific DataBrew recipe corresponding to a particular version.
1854 1855 1856 1857 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1854 def describe_recipe(params = {}, = {}) req = build_request(:describe_recipe, params) req.send_request() end |
#describe_ruleset(params = {}) ⇒ Types::DescribeRulesetResponse
Retrieves detailed information about the ruleset.
1912 1913 1914 1915 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1912 def describe_ruleset(params = {}, = {}) req = build_request(:describe_ruleset, params) req.send_request() end |
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Returns the definition of a specific DataBrew schedule.
1958 1959 1960 1961 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1958 def describe_schedule(params = {}, = {}) req = build_request(:describe_schedule, params) req.send_request() end |
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the DataBrew datasets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2046 2047 2048 2049 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2046 def list_datasets(params = {}, = {}) req = build_request(:list_datasets, params) req.send_request() end |
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists all of the previous runs of a particular DataBrew job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2136 2137 2138 2139 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2136 def list_job_runs(params = {}, = {}) req = build_request(:list_job_runs, params) req.send_request() end |
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists all of the DataBrew jobs that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2241 2242 2243 2244 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2241 def list_jobs(params = {}, = {}) req = build_request(:list_jobs, params) req.send_request() end |
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Lists all of the DataBrew projects that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2294 2295 2296 2297 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2294 def list_projects(params = {}, = {}) req = build_request(:list_projects, params) req.send_request() end |
#list_recipe_versions(params = {}) ⇒ Types::ListRecipeVersionsResponse
Lists the versions of a particular DataBrew recipe, except for ‘LATEST_WORKING`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2357 2358 2359 2360 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2357 def list_recipe_versions(params = {}, = {}) req = build_request(:list_recipe_versions, params) req.send_request() end |
#list_recipes(params = {}) ⇒ Types::ListRecipesResponse
Lists all of the DataBrew recipes that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2423 2424 2425 2426 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2423 def list_recipes(params = {}, = {}) req = build_request(:list_recipes, params) req.send_request() end |
#list_rulesets(params = {}) ⇒ Types::ListRulesetsResponse
List all rulesets available in the current account or rulesets associated with a specific resource (dataset).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2481 2482 2483 2484 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2481 def list_rulesets(params = {}, = {}) req = build_request(:list_rulesets, params) req.send_request() end |
#list_schedules(params = {}) ⇒ Types::ListSchedulesResponse
Lists the DataBrew schedules that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2534 2535 2536 2537 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2534 def list_schedules(params = {}, = {}) req = build_request(:list_schedules, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags for a DataBrew resource.
2564 2565 2566 2567 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2564 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#publish_recipe(params = {}) ⇒ Types::PublishRecipeResponse
Publishes a new version of a DataBrew recipe.
2597 2598 2599 2600 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2597 def publish_recipe(params = {}, = {}) req = build_request(:publish_recipe, params) req.send_request() end |
#send_project_session_action(params = {}) ⇒ Types::SendProjectSessionActionResponse
Performs a recipe step within an interactive DataBrew session that’s currently open.
2675 2676 2677 2678 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2675 def send_project_session_action(params = {}, = {}) req = build_request(:send_project_session_action, params) req.send_request() end |
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Runs a DataBrew job.
2703 2704 2705 2706 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2703 def start_job_run(params = {}, = {}) req = build_request(:start_job_run, params) req.send_request() end |
#start_project_session(params = {}) ⇒ Types::StartProjectSessionResponse
Creates an interactive session, enabling you to manipulate data in a DataBrew project.
2739 2740 2741 2742 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2739 def start_project_session(params = {}, = {}) req = build_request(:start_project_session, params) req.send_request() end |
#stop_job_run(params = {}) ⇒ Types::StopJobRunResponse
Stops a particular run of a job.
2771 2772 2773 2774 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2771 def stop_job_run(params = {}, = {}) req = build_request(:stop_job_run, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule.
2802 2803 2804 2805 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2802 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a DataBrew resource.
2829 2830 2831 2832 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2829 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Modifies the definition of an existing DataBrew dataset.
2949 2950 2951 2952 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2949 def update_dataset(params = {}, = {}) req = build_request(:update_dataset, params) req.send_request() end |
#update_profile_job(params = {}) ⇒ Types::UpdateProfileJobResponse
Modifies the definition of an existing profile job.
3097 3098 3099 3100 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3097 def update_profile_job(params = {}, = {}) req = build_request(:update_profile_job, params) req.send_request() end |
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Modifies the definition of an existing DataBrew project.
3140 3141 3142 3143 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3140 def update_project(params = {}, = {}) req = build_request(:update_project, params) req.send_request() end |
#update_recipe(params = {}) ⇒ Types::UpdateRecipeResponse
Modifies the definition of the ‘LATEST_WORKING` version of a DataBrew recipe.
3194 3195 3196 3197 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3194 def update_recipe(params = {}, = {}) req = build_request(:update_recipe, params) req.send_request() end |
#update_recipe_job(params = {}) ⇒ Types::UpdateRecipeJobResponse
Modifies the definition of an existing DataBrew recipe job.
3326 3327 3328 3329 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3326 def update_recipe_job(params = {}, = {}) req = build_request(:update_recipe_job, params) req.send_request() end |
#update_ruleset(params = {}) ⇒ Types::UpdateRulesetResponse
Updates specified ruleset.
3383 3384 3385 3386 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3383 def update_ruleset(params = {}, = {}) req = build_request(:update_ruleset, params) req.send_request() end |
#update_schedule(params = {}) ⇒ Types::UpdateScheduleResponse
Modifies the definition of an existing DataBrew schedule.
3425 3426 3427 3428 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3425 def update_schedule(params = {}, = {}) req = build_request(:update_schedule, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3454 3455 3456 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3454 def waiter_names [] end |