Class: Aws::GlueDataBrew::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::GlueDataBrew::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-gluedatabrew/client.rb
Overview
An API client for GlueDataBrew. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::GlueDataBrew::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_delete_recipe_version(params = {}) ⇒ Types::BatchDeleteRecipeVersionResponse
Deletes one or more versions of a recipe at a time.
-
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new DataBrew dataset.
-
#create_profile_job(params = {}) ⇒ Types::CreateProfileJobResponse
Creates a new job to analyze a dataset and create its data profile.
-
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a new DataBrew project.
-
#create_recipe(params = {}) ⇒ Types::CreateRecipeResponse
Creates a new DataBrew recipe.
-
#create_recipe_job(params = {}) ⇒ Types::CreateRecipeJobResponse
Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe.
-
#create_ruleset(params = {}) ⇒ Types::CreateRulesetResponse
Creates a new ruleset that can be used in a profile job to validate the data quality of a dataset.
-
#create_schedule(params = {}) ⇒ Types::CreateScheduleResponse
Creates a new schedule for one or more DataBrew jobs.
-
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a dataset from DataBrew.
-
#delete_job(params = {}) ⇒ Types::DeleteJobResponse
Deletes the specified DataBrew job.
-
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes an existing DataBrew project.
-
#delete_recipe_version(params = {}) ⇒ Types::DeleteRecipeVersionResponse
Deletes a single version of a DataBrew recipe.
-
#delete_ruleset(params = {}) ⇒ Types::DeleteRulesetResponse
Deletes a ruleset.
-
#delete_schedule(params = {}) ⇒ Types::DeleteScheduleResponse
Deletes the specified DataBrew schedule.
-
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns the definition of a specific DataBrew dataset.
-
#describe_job(params = {}) ⇒ Types::DescribeJobResponse
Returns the definition of a specific DataBrew job.
-
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Represents one run of a DataBrew job.
-
#describe_project(params = {}) ⇒ Types::DescribeProjectResponse
Returns the definition of a specific DataBrew project.
-
#describe_recipe(params = {}) ⇒ Types::DescribeRecipeResponse
Returns the definition of a specific DataBrew recipe corresponding to a particular version.
-
#describe_ruleset(params = {}) ⇒ Types::DescribeRulesetResponse
Retrieves detailed information about the ruleset.
-
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Returns the definition of a specific DataBrew schedule.
-
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the DataBrew datasets.
-
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists all of the previous runs of a particular DataBrew job.
-
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists all of the DataBrew jobs that are defined.
-
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Lists all of the DataBrew projects that are defined.
-
#list_recipe_versions(params = {}) ⇒ Types::ListRecipeVersionsResponse
Lists the versions of a particular DataBrew recipe, except for ‘LATEST_WORKING`.
-
#list_recipes(params = {}) ⇒ Types::ListRecipesResponse
Lists all of the DataBrew recipes that are defined.
-
#list_rulesets(params = {}) ⇒ Types::ListRulesetsResponse
List all rulesets available in the current account or rulesets associated with a specific resource (dataset).
-
#list_schedules(params = {}) ⇒ Types::ListSchedulesResponse
Lists the DataBrew schedules that are defined.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags for a DataBrew resource.
-
#publish_recipe(params = {}) ⇒ Types::PublishRecipeResponse
Publishes a new version of a DataBrew recipe.
-
#send_project_session_action(params = {}) ⇒ Types::SendProjectSessionActionResponse
Performs a recipe step within an interactive DataBrew session that’s currently open.
-
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Runs a DataBrew job.
-
#start_project_session(params = {}) ⇒ Types::StartProjectSessionResponse
Creates an interactive session, enabling you to manipulate data in a DataBrew project.
-
#stop_job_run(params = {}) ⇒ Types::StopJobRunResponse
Stops a particular run of a job.
-
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule.
-
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a DataBrew resource.
-
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Modifies the definition of an existing DataBrew dataset.
-
#update_profile_job(params = {}) ⇒ Types::UpdateProfileJobResponse
Modifies the definition of an existing profile job.
-
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Modifies the definition of an existing DataBrew project.
-
#update_recipe(params = {}) ⇒ Types::UpdateRecipeResponse
Modifies the definition of the ‘LATEST_WORKING` version of a DataBrew recipe.
-
#update_recipe_job(params = {}) ⇒ Types::UpdateRecipeJobResponse
Modifies the definition of an existing DataBrew recipe job.
-
#update_ruleset(params = {}) ⇒ Types::UpdateRulesetResponse
Updates specified ruleset.
-
#update_schedule(params = {}) ⇒ Types::UpdateScheduleResponse
Modifies the definition of an existing DataBrew schedule.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
413 414 415 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 413 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3398 3399 3400 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3398 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3401 3402 3403 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3401 def errors_module Errors end |
Instance Method Details
#batch_delete_recipe_version(params = {}) ⇒ Types::BatchDeleteRecipeVersionResponse
Deletes one or more versions of a recipe at a time.
The entire request will be rejected if:
-
The recipe does not exist.
-
There is an invalid version identifier in the list of versions.
-
The version list is empty.
-
The version list size exceeds 50.
-
The version list contains duplicate entries.
The request will complete successfully, but with partial failures, if:
-
A version does not exist.
-
A version is being used by a job.
-
You specify ‘LATEST_WORKING`, but it’s being used by a project.
-
The version fails to be deleted.
The ‘LATEST_WORKING` version will only be deleted if the recipe has no other versions. If you try to delete `LATEST_WORKING` while other versions exist (or if they can’t be deleted), then ‘LATEST_WORKING` will be listed as partial failure in the response.
480 481 482 483 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 480 def batch_delete_recipe_version(params = {}, = {}) req = build_request(:batch_delete_recipe_version, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3376 3377 3378 3379 3380 3381 3382 3383 3384 3385 3386 3387 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3376 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-gluedatabrew' context[:gem_version] = '1.39.0' Seahorse::Client::Request.new(handlers, context) end |
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new DataBrew dataset.
607 608 609 610 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 607 def create_dataset(params = {}, = {}) req = build_request(:create_dataset, params) req.send_request() end |
#create_profile_job(params = {}) ⇒ Types::CreateProfileJobResponse
Creates a new job to analyze a dataset and create its data profile.
766 767 768 769 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 766 def create_profile_job(params = {}, = {}) req = build_request(:create_profile_job, params) req.send_request() end |
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a new DataBrew project.
822 823 824 825 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 822 def create_project(params = {}, = {}) req = build_request(:create_project, params) req.send_request() end |
#create_recipe(params = {}) ⇒ Types::CreateRecipeResponse
Creates a new DataBrew recipe.
883 884 885 886 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 883 def create_recipe(params = {}, = {}) req = build_request(:create_recipe, params) req.send_request() end |
#create_recipe_job(params = {}) ⇒ Types::CreateRecipeJobResponse
Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe
1039 1040 1041 1042 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1039 def create_recipe_job(params = {}, = {}) req = build_request(:create_recipe_job, params) req.send_request() end |
#create_ruleset(params = {}) ⇒ Types::CreateRulesetResponse
Creates a new ruleset that can be used in a profile job to validate the data quality of a dataset.
1109 1110 1111 1112 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1109 def create_ruleset(params = {}, = {}) req = build_request(:create_ruleset, params) req.send_request() end |
#create_schedule(params = {}) ⇒ Types::CreateScheduleResponse
Creates a new schedule for one or more DataBrew jobs. Jobs can be run at a specific date and time, or at regular intervals.
1159 1160 1161 1162 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1159 def create_schedule(params = {}, = {}) req = build_request(:create_schedule, params) req.send_request() end |
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a dataset from DataBrew.
1187 1188 1189 1190 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1187 def delete_dataset(params = {}, = {}) req = build_request(:delete_dataset, params) req.send_request() end |
#delete_job(params = {}) ⇒ Types::DeleteJobResponse
Deletes the specified DataBrew job.
1215 1216 1217 1218 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1215 def delete_job(params = {}, = {}) req = build_request(:delete_job, params) req.send_request() end |
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes an existing DataBrew project.
1243 1244 1245 1246 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1243 def delete_project(params = {}, = {}) req = build_request(:delete_project, params) req.send_request() end |
#delete_recipe_version(params = {}) ⇒ Types::DeleteRecipeVersionResponse
Deletes a single version of a DataBrew recipe.
1279 1280 1281 1282 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1279 def delete_recipe_version(params = {}, = {}) req = build_request(:delete_recipe_version, params) req.send_request() end |
#delete_ruleset(params = {}) ⇒ Types::DeleteRulesetResponse
Deletes a ruleset.
1307 1308 1309 1310 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1307 def delete_ruleset(params = {}, = {}) req = build_request(:delete_ruleset, params) req.send_request() end |
#delete_schedule(params = {}) ⇒ Types::DeleteScheduleResponse
Deletes the specified DataBrew schedule.
1335 1336 1337 1338 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1335 def delete_schedule(params = {}, = {}) req = build_request(:delete_schedule, params) req.send_request() end |
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns the definition of a specific DataBrew dataset.
1423 1424 1425 1426 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1423 def describe_dataset(params = {}, = {}) req = build_request(:describe_dataset, params) req.send_request() end |
#describe_job(params = {}) ⇒ Types::DescribeJobResponse
Returns the definition of a specific DataBrew job.
1552 1553 1554 1555 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1552 def describe_job(params = {}, = {}) req = build_request(:describe_job, params) req.send_request() end |
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Represents one run of a DataBrew job.
1674 1675 1676 1677 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1674 def describe_job_run(params = {}, = {}) req = build_request(:describe_job_run, params) req.send_request() end |
#describe_project(params = {}) ⇒ Types::DescribeProjectResponse
Returns the definition of a specific DataBrew project.
1730 1731 1732 1733 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1730 def describe_project(params = {}, = {}) req = build_request(:describe_project, params) req.send_request() end |
#describe_recipe(params = {}) ⇒ Types::DescribeRecipeResponse
Returns the definition of a specific DataBrew recipe corresponding to a particular version.
1796 1797 1798 1799 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1796 def describe_recipe(params = {}, = {}) req = build_request(:describe_recipe, params) req.send_request() end |
#describe_ruleset(params = {}) ⇒ Types::DescribeRulesetResponse
Retrieves detailed information about the ruleset.
1854 1855 1856 1857 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1854 def describe_ruleset(params = {}, = {}) req = build_request(:describe_ruleset, params) req.send_request() end |
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Returns the definition of a specific DataBrew schedule.
1900 1901 1902 1903 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1900 def describe_schedule(params = {}, = {}) req = build_request(:describe_schedule, params) req.send_request() end |
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the DataBrew datasets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1988 1989 1990 1991 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1988 def list_datasets(params = {}, = {}) req = build_request(:list_datasets, params) req.send_request() end |
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists all of the previous runs of a particular DataBrew job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2078 2079 2080 2081 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2078 def list_job_runs(params = {}, = {}) req = build_request(:list_job_runs, params) req.send_request() end |
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists all of the DataBrew jobs that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2183 2184 2185 2186 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2183 def list_jobs(params = {}, = {}) req = build_request(:list_jobs, params) req.send_request() end |
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Lists all of the DataBrew projects that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2236 2237 2238 2239 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2236 def list_projects(params = {}, = {}) req = build_request(:list_projects, params) req.send_request() end |
#list_recipe_versions(params = {}) ⇒ Types::ListRecipeVersionsResponse
Lists the versions of a particular DataBrew recipe, except for ‘LATEST_WORKING`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2299 2300 2301 2302 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2299 def list_recipe_versions(params = {}, = {}) req = build_request(:list_recipe_versions, params) req.send_request() end |
#list_recipes(params = {}) ⇒ Types::ListRecipesResponse
Lists all of the DataBrew recipes that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2365 2366 2367 2368 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2365 def list_recipes(params = {}, = {}) req = build_request(:list_recipes, params) req.send_request() end |
#list_rulesets(params = {}) ⇒ Types::ListRulesetsResponse
List all rulesets available in the current account or rulesets associated with a specific resource (dataset).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2423 2424 2425 2426 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2423 def list_rulesets(params = {}, = {}) req = build_request(:list_rulesets, params) req.send_request() end |
#list_schedules(params = {}) ⇒ Types::ListSchedulesResponse
Lists the DataBrew schedules that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2476 2477 2478 2479 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2476 def list_schedules(params = {}, = {}) req = build_request(:list_schedules, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags for a DataBrew resource.
2506 2507 2508 2509 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2506 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#publish_recipe(params = {}) ⇒ Types::PublishRecipeResponse
Publishes a new version of a DataBrew recipe.
2539 2540 2541 2542 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2539 def publish_recipe(params = {}, = {}) req = build_request(:publish_recipe, params) req.send_request() end |
#send_project_session_action(params = {}) ⇒ Types::SendProjectSessionActionResponse
Performs a recipe step within an interactive DataBrew session that’s currently open.
2617 2618 2619 2620 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2617 def send_project_session_action(params = {}, = {}) req = build_request(:send_project_session_action, params) req.send_request() end |
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Runs a DataBrew job.
2645 2646 2647 2648 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2645 def start_job_run(params = {}, = {}) req = build_request(:start_job_run, params) req.send_request() end |
#start_project_session(params = {}) ⇒ Types::StartProjectSessionResponse
Creates an interactive session, enabling you to manipulate data in a DataBrew project.
2681 2682 2683 2684 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2681 def start_project_session(params = {}, = {}) req = build_request(:start_project_session, params) req.send_request() end |
#stop_job_run(params = {}) ⇒ Types::StopJobRunResponse
Stops a particular run of a job.
2713 2714 2715 2716 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2713 def stop_job_run(params = {}, = {}) req = build_request(:stop_job_run, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule.
2744 2745 2746 2747 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2744 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a DataBrew resource.
2771 2772 2773 2774 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2771 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Modifies the definition of an existing DataBrew dataset.
2891 2892 2893 2894 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2891 def update_dataset(params = {}, = {}) req = build_request(:update_dataset, params) req.send_request() end |
#update_profile_job(params = {}) ⇒ Types::UpdateProfileJobResponse
Modifies the definition of an existing profile job.
3039 3040 3041 3042 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3039 def update_profile_job(params = {}, = {}) req = build_request(:update_profile_job, params) req.send_request() end |
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Modifies the definition of an existing DataBrew project.
3082 3083 3084 3085 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3082 def update_project(params = {}, = {}) req = build_request(:update_project, params) req.send_request() end |
#update_recipe(params = {}) ⇒ Types::UpdateRecipeResponse
Modifies the definition of the ‘LATEST_WORKING` version of a DataBrew recipe.
3136 3137 3138 3139 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3136 def update_recipe(params = {}, = {}) req = build_request(:update_recipe, params) req.send_request() end |
#update_recipe_job(params = {}) ⇒ Types::UpdateRecipeJobResponse
Modifies the definition of an existing DataBrew recipe job.
3268 3269 3270 3271 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3268 def update_recipe_job(params = {}, = {}) req = build_request(:update_recipe_job, params) req.send_request() end |
#update_ruleset(params = {}) ⇒ Types::UpdateRulesetResponse
Updates specified ruleset.
3325 3326 3327 3328 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3325 def update_ruleset(params = {}, = {}) req = build_request(:update_ruleset, params) req.send_request() end |
#update_schedule(params = {}) ⇒ Types::UpdateScheduleResponse
Modifies the definition of an existing DataBrew schedule.
3367 3368 3369 3370 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3367 def update_schedule(params = {}, = {}) req = build_request(:update_schedule, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3391 3392 3393 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3391 def waiter_names [] end |