Class: Aws::GlueDataBrew::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::GlueDataBrew::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-gluedatabrew/client.rb
Overview
An API client for GlueDataBrew. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::GlueDataBrew::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_delete_recipe_version(params = {}) ⇒ Types::BatchDeleteRecipeVersionResponse
Deletes one or more versions of a recipe at a time.
-
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new DataBrew dataset.
-
#create_profile_job(params = {}) ⇒ Types::CreateProfileJobResponse
Creates a new job to analyze a dataset and create its data profile.
-
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a new DataBrew project.
-
#create_recipe(params = {}) ⇒ Types::CreateRecipeResponse
Creates a new DataBrew recipe.
-
#create_recipe_job(params = {}) ⇒ Types::CreateRecipeJobResponse
Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe.
-
#create_ruleset(params = {}) ⇒ Types::CreateRulesetResponse
Creates a new ruleset that can be used in a profile job to validate the data quality of a dataset.
-
#create_schedule(params = {}) ⇒ Types::CreateScheduleResponse
Creates a new schedule for one or more DataBrew jobs.
-
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a dataset from DataBrew.
-
#delete_job(params = {}) ⇒ Types::DeleteJobResponse
Deletes the specified DataBrew job.
-
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes an existing DataBrew project.
-
#delete_recipe_version(params = {}) ⇒ Types::DeleteRecipeVersionResponse
Deletes a single version of a DataBrew recipe.
-
#delete_ruleset(params = {}) ⇒ Types::DeleteRulesetResponse
Deletes a ruleset.
-
#delete_schedule(params = {}) ⇒ Types::DeleteScheduleResponse
Deletes the specified DataBrew schedule.
-
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns the definition of a specific DataBrew dataset.
-
#describe_job(params = {}) ⇒ Types::DescribeJobResponse
Returns the definition of a specific DataBrew job.
-
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Represents one run of a DataBrew job.
-
#describe_project(params = {}) ⇒ Types::DescribeProjectResponse
Returns the definition of a specific DataBrew project.
-
#describe_recipe(params = {}) ⇒ Types::DescribeRecipeResponse
Returns the definition of a specific DataBrew recipe corresponding to a particular version.
-
#describe_ruleset(params = {}) ⇒ Types::DescribeRulesetResponse
Retrieves detailed information about the ruleset.
-
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Returns the definition of a specific DataBrew schedule.
-
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the DataBrew datasets.
-
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists all of the previous runs of a particular DataBrew job.
-
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists all of the DataBrew jobs that are defined.
-
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Lists all of the DataBrew projects that are defined.
-
#list_recipe_versions(params = {}) ⇒ Types::ListRecipeVersionsResponse
Lists the versions of a particular DataBrew recipe, except for ‘LATEST_WORKING`.
-
#list_recipes(params = {}) ⇒ Types::ListRecipesResponse
Lists all of the DataBrew recipes that are defined.
-
#list_rulesets(params = {}) ⇒ Types::ListRulesetsResponse
List all rulesets available in the current account or rulesets associated with a specific resource (dataset).
-
#list_schedules(params = {}) ⇒ Types::ListSchedulesResponse
Lists the DataBrew schedules that are defined.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags for a DataBrew resource.
-
#publish_recipe(params = {}) ⇒ Types::PublishRecipeResponse
Publishes a new version of a DataBrew recipe.
-
#send_project_session_action(params = {}) ⇒ Types::SendProjectSessionActionResponse
Performs a recipe step within an interactive DataBrew session that’s currently open.
-
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Runs a DataBrew job.
-
#start_project_session(params = {}) ⇒ Types::StartProjectSessionResponse
Creates an interactive session, enabling you to manipulate data in a DataBrew project.
-
#stop_job_run(params = {}) ⇒ Types::StopJobRunResponse
Stops a particular run of a job.
-
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule.
-
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a DataBrew resource.
-
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Modifies the definition of an existing DataBrew dataset.
-
#update_profile_job(params = {}) ⇒ Types::UpdateProfileJobResponse
Modifies the definition of an existing profile job.
-
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Modifies the definition of an existing DataBrew project.
-
#update_recipe(params = {}) ⇒ Types::UpdateRecipeResponse
Modifies the definition of the ‘LATEST_WORKING` version of a DataBrew recipe.
-
#update_recipe_job(params = {}) ⇒ Types::UpdateRecipeJobResponse
Modifies the definition of an existing DataBrew recipe job.
-
#update_ruleset(params = {}) ⇒ Types::UpdateRulesetResponse
Updates specified ruleset.
-
#update_schedule(params = {}) ⇒ Types::UpdateScheduleResponse
Modifies the definition of an existing DataBrew schedule.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
381 382 383 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 381 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3366 3367 3368 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3366 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3369 3370 3371 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3369 def errors_module Errors end |
Instance Method Details
#batch_delete_recipe_version(params = {}) ⇒ Types::BatchDeleteRecipeVersionResponse
Deletes one or more versions of a recipe at a time.
The entire request will be rejected if:
-
The recipe does not exist.
-
There is an invalid version identifier in the list of versions.
-
The version list is empty.
-
The version list size exceeds 50.
-
The version list contains duplicate entries.
The request will complete successfully, but with partial failures, if:
-
A version does not exist.
-
A version is being used by a job.
-
You specify ‘LATEST_WORKING`, but it’s being used by a project.
-
The version fails to be deleted.
The ‘LATEST_WORKING` version will only be deleted if the recipe has no other versions. If you try to delete `LATEST_WORKING` while other versions exist (or if they can’t be deleted), then ‘LATEST_WORKING` will be listed as partial failure in the response.
448 449 450 451 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 448 def batch_delete_recipe_version(params = {}, = {}) req = build_request(:batch_delete_recipe_version, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3344 3345 3346 3347 3348 3349 3350 3351 3352 3353 3354 3355 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3344 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-gluedatabrew' context[:gem_version] = '1.29.0' Seahorse::Client::Request.new(handlers, context) end |
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new DataBrew dataset.
575 576 577 578 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 575 def create_dataset(params = {}, = {}) req = build_request(:create_dataset, params) req.send_request() end |
#create_profile_job(params = {}) ⇒ Types::CreateProfileJobResponse
Creates a new job to analyze a dataset and create its data profile.
734 735 736 737 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 734 def create_profile_job(params = {}, = {}) req = build_request(:create_profile_job, params) req.send_request() end |
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a new DataBrew project.
790 791 792 793 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 790 def create_project(params = {}, = {}) req = build_request(:create_project, params) req.send_request() end |
#create_recipe(params = {}) ⇒ Types::CreateRecipeResponse
Creates a new DataBrew recipe.
851 852 853 854 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 851 def create_recipe(params = {}, = {}) req = build_request(:create_recipe, params) req.send_request() end |
#create_recipe_job(params = {}) ⇒ Types::CreateRecipeJobResponse
Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe
1007 1008 1009 1010 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1007 def create_recipe_job(params = {}, = {}) req = build_request(:create_recipe_job, params) req.send_request() end |
#create_ruleset(params = {}) ⇒ Types::CreateRulesetResponse
Creates a new ruleset that can be used in a profile job to validate the data quality of a dataset.
1077 1078 1079 1080 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1077 def create_ruleset(params = {}, = {}) req = build_request(:create_ruleset, params) req.send_request() end |
#create_schedule(params = {}) ⇒ Types::CreateScheduleResponse
Creates a new schedule for one or more DataBrew jobs. Jobs can be run at a specific date and time, or at regular intervals.
1127 1128 1129 1130 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1127 def create_schedule(params = {}, = {}) req = build_request(:create_schedule, params) req.send_request() end |
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a dataset from DataBrew.
1155 1156 1157 1158 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1155 def delete_dataset(params = {}, = {}) req = build_request(:delete_dataset, params) req.send_request() end |
#delete_job(params = {}) ⇒ Types::DeleteJobResponse
Deletes the specified DataBrew job.
1183 1184 1185 1186 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1183 def delete_job(params = {}, = {}) req = build_request(:delete_job, params) req.send_request() end |
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes an existing DataBrew project.
1211 1212 1213 1214 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1211 def delete_project(params = {}, = {}) req = build_request(:delete_project, params) req.send_request() end |
#delete_recipe_version(params = {}) ⇒ Types::DeleteRecipeVersionResponse
Deletes a single version of a DataBrew recipe.
1247 1248 1249 1250 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1247 def delete_recipe_version(params = {}, = {}) req = build_request(:delete_recipe_version, params) req.send_request() end |
#delete_ruleset(params = {}) ⇒ Types::DeleteRulesetResponse
Deletes a ruleset.
1275 1276 1277 1278 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1275 def delete_ruleset(params = {}, = {}) req = build_request(:delete_ruleset, params) req.send_request() end |
#delete_schedule(params = {}) ⇒ Types::DeleteScheduleResponse
Deletes the specified DataBrew schedule.
1303 1304 1305 1306 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1303 def delete_schedule(params = {}, = {}) req = build_request(:delete_schedule, params) req.send_request() end |
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns the definition of a specific DataBrew dataset.
1391 1392 1393 1394 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1391 def describe_dataset(params = {}, = {}) req = build_request(:describe_dataset, params) req.send_request() end |
#describe_job(params = {}) ⇒ Types::DescribeJobResponse
Returns the definition of a specific DataBrew job.
1520 1521 1522 1523 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1520 def describe_job(params = {}, = {}) req = build_request(:describe_job, params) req.send_request() end |
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Represents one run of a DataBrew job.
1642 1643 1644 1645 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1642 def describe_job_run(params = {}, = {}) req = build_request(:describe_job_run, params) req.send_request() end |
#describe_project(params = {}) ⇒ Types::DescribeProjectResponse
Returns the definition of a specific DataBrew project.
1698 1699 1700 1701 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1698 def describe_project(params = {}, = {}) req = build_request(:describe_project, params) req.send_request() end |
#describe_recipe(params = {}) ⇒ Types::DescribeRecipeResponse
Returns the definition of a specific DataBrew recipe corresponding to a particular version.
1764 1765 1766 1767 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1764 def describe_recipe(params = {}, = {}) req = build_request(:describe_recipe, params) req.send_request() end |
#describe_ruleset(params = {}) ⇒ Types::DescribeRulesetResponse
Retrieves detailed information about the ruleset.
1822 1823 1824 1825 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1822 def describe_ruleset(params = {}, = {}) req = build_request(:describe_ruleset, params) req.send_request() end |
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Returns the definition of a specific DataBrew schedule.
1868 1869 1870 1871 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1868 def describe_schedule(params = {}, = {}) req = build_request(:describe_schedule, params) req.send_request() end |
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the DataBrew datasets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1956 1957 1958 1959 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1956 def list_datasets(params = {}, = {}) req = build_request(:list_datasets, params) req.send_request() end |
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists all of the previous runs of a particular DataBrew job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2046 2047 2048 2049 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2046 def list_job_runs(params = {}, = {}) req = build_request(:list_job_runs, params) req.send_request() end |
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists all of the DataBrew jobs that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2151 2152 2153 2154 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2151 def list_jobs(params = {}, = {}) req = build_request(:list_jobs, params) req.send_request() end |
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Lists all of the DataBrew projects that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2204 2205 2206 2207 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2204 def list_projects(params = {}, = {}) req = build_request(:list_projects, params) req.send_request() end |
#list_recipe_versions(params = {}) ⇒ Types::ListRecipeVersionsResponse
Lists the versions of a particular DataBrew recipe, except for ‘LATEST_WORKING`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2267 2268 2269 2270 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2267 def list_recipe_versions(params = {}, = {}) req = build_request(:list_recipe_versions, params) req.send_request() end |
#list_recipes(params = {}) ⇒ Types::ListRecipesResponse
Lists all of the DataBrew recipes that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2333 2334 2335 2336 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2333 def list_recipes(params = {}, = {}) req = build_request(:list_recipes, params) req.send_request() end |
#list_rulesets(params = {}) ⇒ Types::ListRulesetsResponse
List all rulesets available in the current account or rulesets associated with a specific resource (dataset).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2391 2392 2393 2394 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2391 def list_rulesets(params = {}, = {}) req = build_request(:list_rulesets, params) req.send_request() end |
#list_schedules(params = {}) ⇒ Types::ListSchedulesResponse
Lists the DataBrew schedules that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2444 2445 2446 2447 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2444 def list_schedules(params = {}, = {}) req = build_request(:list_schedules, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags for a DataBrew resource.
2474 2475 2476 2477 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2474 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#publish_recipe(params = {}) ⇒ Types::PublishRecipeResponse
Publishes a new version of a DataBrew recipe.
2507 2508 2509 2510 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2507 def publish_recipe(params = {}, = {}) req = build_request(:publish_recipe, params) req.send_request() end |
#send_project_session_action(params = {}) ⇒ Types::SendProjectSessionActionResponse
Performs a recipe step within an interactive DataBrew session that’s currently open.
2585 2586 2587 2588 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2585 def send_project_session_action(params = {}, = {}) req = build_request(:send_project_session_action, params) req.send_request() end |
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Runs a DataBrew job.
2613 2614 2615 2616 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2613 def start_job_run(params = {}, = {}) req = build_request(:start_job_run, params) req.send_request() end |
#start_project_session(params = {}) ⇒ Types::StartProjectSessionResponse
Creates an interactive session, enabling you to manipulate data in a DataBrew project.
2649 2650 2651 2652 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2649 def start_project_session(params = {}, = {}) req = build_request(:start_project_session, params) req.send_request() end |
#stop_job_run(params = {}) ⇒ Types::StopJobRunResponse
Stops a particular run of a job.
2681 2682 2683 2684 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2681 def stop_job_run(params = {}, = {}) req = build_request(:stop_job_run, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule.
2712 2713 2714 2715 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2712 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a DataBrew resource.
2739 2740 2741 2742 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2739 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Modifies the definition of an existing DataBrew dataset.
2859 2860 2861 2862 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2859 def update_dataset(params = {}, = {}) req = build_request(:update_dataset, params) req.send_request() end |
#update_profile_job(params = {}) ⇒ Types::UpdateProfileJobResponse
Modifies the definition of an existing profile job.
3007 3008 3009 3010 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3007 def update_profile_job(params = {}, = {}) req = build_request(:update_profile_job, params) req.send_request() end |
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Modifies the definition of an existing DataBrew project.
3050 3051 3052 3053 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3050 def update_project(params = {}, = {}) req = build_request(:update_project, params) req.send_request() end |
#update_recipe(params = {}) ⇒ Types::UpdateRecipeResponse
Modifies the definition of the ‘LATEST_WORKING` version of a DataBrew recipe.
3104 3105 3106 3107 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3104 def update_recipe(params = {}, = {}) req = build_request(:update_recipe, params) req.send_request() end |
#update_recipe_job(params = {}) ⇒ Types::UpdateRecipeJobResponse
Modifies the definition of an existing DataBrew recipe job.
3236 3237 3238 3239 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3236 def update_recipe_job(params = {}, = {}) req = build_request(:update_recipe_job, params) req.send_request() end |
#update_ruleset(params = {}) ⇒ Types::UpdateRulesetResponse
Updates specified ruleset.
3293 3294 3295 3296 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3293 def update_ruleset(params = {}, = {}) req = build_request(:update_ruleset, params) req.send_request() end |
#update_schedule(params = {}) ⇒ Types::UpdateScheduleResponse
Modifies the definition of an existing DataBrew schedule.
3335 3336 3337 3338 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3335 def update_schedule(params = {}, = {}) req = build_request(:update_schedule, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3359 3360 3361 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3359 def waiter_names [] end |