Class: Aws::GlueDataBrew::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::GlueDataBrew::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-gluedatabrew/client.rb
Overview
An API client for GlueDataBrew. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::GlueDataBrew::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_delete_recipe_version(params = {}) ⇒ Types::BatchDeleteRecipeVersionResponse
Deletes one or more versions of a recipe at a time.
-
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new DataBrew dataset.
-
#create_profile_job(params = {}) ⇒ Types::CreateProfileJobResponse
Creates a new job to analyze a dataset and create its data profile.
-
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a new DataBrew project.
-
#create_recipe(params = {}) ⇒ Types::CreateRecipeResponse
Creates a new DataBrew recipe.
-
#create_recipe_job(params = {}) ⇒ Types::CreateRecipeJobResponse
Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe.
-
#create_ruleset(params = {}) ⇒ Types::CreateRulesetResponse
Creates a new ruleset that can be used in a profile job to validate the data quality of a dataset.
-
#create_schedule(params = {}) ⇒ Types::CreateScheduleResponse
Creates a new schedule for one or more DataBrew jobs.
-
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a dataset from DataBrew.
-
#delete_job(params = {}) ⇒ Types::DeleteJobResponse
Deletes the specified DataBrew job.
-
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes an existing DataBrew project.
-
#delete_recipe_version(params = {}) ⇒ Types::DeleteRecipeVersionResponse
Deletes a single version of a DataBrew recipe.
-
#delete_ruleset(params = {}) ⇒ Types::DeleteRulesetResponse
Deletes a ruleset.
-
#delete_schedule(params = {}) ⇒ Types::DeleteScheduleResponse
Deletes the specified DataBrew schedule.
-
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns the definition of a specific DataBrew dataset.
-
#describe_job(params = {}) ⇒ Types::DescribeJobResponse
Returns the definition of a specific DataBrew job.
-
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Represents one run of a DataBrew job.
-
#describe_project(params = {}) ⇒ Types::DescribeProjectResponse
Returns the definition of a specific DataBrew project.
-
#describe_recipe(params = {}) ⇒ Types::DescribeRecipeResponse
Returns the definition of a specific DataBrew recipe corresponding to a particular version.
-
#describe_ruleset(params = {}) ⇒ Types::DescribeRulesetResponse
Retrieves detailed information about the ruleset.
-
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Returns the definition of a specific DataBrew schedule.
-
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the DataBrew datasets.
-
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists all of the previous runs of a particular DataBrew job.
-
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists all of the DataBrew jobs that are defined.
-
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Lists all of the DataBrew projects that are defined.
-
#list_recipe_versions(params = {}) ⇒ Types::ListRecipeVersionsResponse
Lists the versions of a particular DataBrew recipe, except for `LATEST_WORKING`.
-
#list_recipes(params = {}) ⇒ Types::ListRecipesResponse
Lists all of the DataBrew recipes that are defined.
-
#list_rulesets(params = {}) ⇒ Types::ListRulesetsResponse
List all rulesets available in the current account or rulesets associated with a specific resource (dataset).
-
#list_schedules(params = {}) ⇒ Types::ListSchedulesResponse
Lists the DataBrew schedules that are defined.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags for a DataBrew resource.
-
#publish_recipe(params = {}) ⇒ Types::PublishRecipeResponse
Publishes a new version of a DataBrew recipe.
-
#send_project_session_action(params = {}) ⇒ Types::SendProjectSessionActionResponse
Performs a recipe step within an interactive DataBrew session that's currently open.
-
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Runs a DataBrew job.
-
#start_project_session(params = {}) ⇒ Types::StartProjectSessionResponse
Creates an interactive session, enabling you to manipulate data in a DataBrew project.
-
#stop_job_run(params = {}) ⇒ Types::StopJobRunResponse
Stops a particular run of a job.
-
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule.
-
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a DataBrew resource.
-
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Modifies the definition of an existing DataBrew dataset.
-
#update_profile_job(params = {}) ⇒ Types::UpdateProfileJobResponse
Modifies the definition of an existing profile job.
-
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Modifies the definition of an existing DataBrew project.
-
#update_recipe(params = {}) ⇒ Types::UpdateRecipeResponse
Modifies the definition of the `LATEST_WORKING` version of a DataBrew recipe.
-
#update_recipe_job(params = {}) ⇒ Types::UpdateRecipeJobResponse
Modifies the definition of an existing DataBrew recipe job.
-
#update_ruleset(params = {}) ⇒ Types::UpdateRulesetResponse
Updates specified ruleset.
-
#update_schedule(params = {}) ⇒ Types::UpdateScheduleResponse
Modifies the definition of an existing DataBrew schedule.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
346 347 348 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 346 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3325 3326 3327 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3325 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3328 3329 3330 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3328 def errors_module Errors end |
Instance Method Details
#batch_delete_recipe_version(params = {}) ⇒ Types::BatchDeleteRecipeVersionResponse
Deletes one or more versions of a recipe at a time.
The entire request will be rejected if:
-
The recipe does not exist.
-
There is an invalid version identifier in the list of versions.
-
The version list is empty.
-
The version list size exceeds 50.
-
The version list contains duplicate entries.
The request will complete successfully, but with partial failures, if:
-
A version does not exist.
-
A version is being used by a job.
-
You specify `LATEST_WORKING`, but it's being used by a project.
-
The version fails to be deleted.
The `LATEST_WORKING` version will only be deleted if the recipe has no other versions. If you try to delete `LATEST_WORKING` while other versions exist (or if they can't be deleted), then `LATEST_WORKING` will be listed as partial failure in the response.
413 414 415 416 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 413 def batch_delete_recipe_version(params = {}, = {}) req = build_request(:batch_delete_recipe_version, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3303 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-gluedatabrew' context[:gem_version] = '1.20.0' Seahorse::Client::Request.new(handlers, context) end |
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new DataBrew dataset.
540 541 542 543 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 540 def create_dataset(params = {}, = {}) req = build_request(:create_dataset, params) req.send_request() end |
#create_profile_job(params = {}) ⇒ Types::CreateProfileJobResponse
Creates a new job to analyze a dataset and create its data profile.
699 700 701 702 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 699 def create_profile_job(params = {}, = {}) req = build_request(:create_profile_job, params) req.send_request() end |
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a new DataBrew project.
755 756 757 758 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 755 def create_project(params = {}, = {}) req = build_request(:create_project, params) req.send_request() end |
#create_recipe(params = {}) ⇒ Types::CreateRecipeResponse
Creates a new DataBrew recipe.
816 817 818 819 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 816 def create_recipe(params = {}, = {}) req = build_request(:create_recipe, params) req.send_request() end |
#create_recipe_job(params = {}) ⇒ Types::CreateRecipeJobResponse
Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe
971 972 973 974 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 971 def create_recipe_job(params = {}, = {}) req = build_request(:create_recipe_job, params) req.send_request() end |
#create_ruleset(params = {}) ⇒ Types::CreateRulesetResponse
Creates a new ruleset that can be used in a profile job to validate the data quality of a dataset.
1041 1042 1043 1044 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1041 def create_ruleset(params = {}, = {}) req = build_request(:create_ruleset, params) req.send_request() end |
#create_schedule(params = {}) ⇒ Types::CreateScheduleResponse
Creates a new schedule for one or more DataBrew jobs. Jobs can be run at a specific date and time, or at regular intervals.
1091 1092 1093 1094 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1091 def create_schedule(params = {}, = {}) req = build_request(:create_schedule, params) req.send_request() end |
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a dataset from DataBrew.
1119 1120 1121 1122 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1119 def delete_dataset(params = {}, = {}) req = build_request(:delete_dataset, params) req.send_request() end |
#delete_job(params = {}) ⇒ Types::DeleteJobResponse
Deletes the specified DataBrew job.
1147 1148 1149 1150 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1147 def delete_job(params = {}, = {}) req = build_request(:delete_job, params) req.send_request() end |
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes an existing DataBrew project.
1175 1176 1177 1178 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1175 def delete_project(params = {}, = {}) req = build_request(:delete_project, params) req.send_request() end |
#delete_recipe_version(params = {}) ⇒ Types::DeleteRecipeVersionResponse
Deletes a single version of a DataBrew recipe.
1211 1212 1213 1214 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1211 def delete_recipe_version(params = {}, = {}) req = build_request(:delete_recipe_version, params) req.send_request() end |
#delete_ruleset(params = {}) ⇒ Types::DeleteRulesetResponse
Deletes a ruleset.
1239 1240 1241 1242 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1239 def delete_ruleset(params = {}, = {}) req = build_request(:delete_ruleset, params) req.send_request() end |
#delete_schedule(params = {}) ⇒ Types::DeleteScheduleResponse
Deletes the specified DataBrew schedule.
1267 1268 1269 1270 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1267 def delete_schedule(params = {}, = {}) req = build_request(:delete_schedule, params) req.send_request() end |
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns the definition of a specific DataBrew dataset.
1355 1356 1357 1358 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1355 def describe_dataset(params = {}, = {}) req = build_request(:describe_dataset, params) req.send_request() end |
#describe_job(params = {}) ⇒ Types::DescribeJobResponse
Returns the definition of a specific DataBrew job.
1483 1484 1485 1486 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1483 def describe_job(params = {}, = {}) req = build_request(:describe_job, params) req.send_request() end |
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Represents one run of a DataBrew job.
1604 1605 1606 1607 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1604 def describe_job_run(params = {}, = {}) req = build_request(:describe_job_run, params) req.send_request() end |
#describe_project(params = {}) ⇒ Types::DescribeProjectResponse
Returns the definition of a specific DataBrew project.
1660 1661 1662 1663 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1660 def describe_project(params = {}, = {}) req = build_request(:describe_project, params) req.send_request() end |
#describe_recipe(params = {}) ⇒ Types::DescribeRecipeResponse
Returns the definition of a specific DataBrew recipe corresponding to a particular version.
1726 1727 1728 1729 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1726 def describe_recipe(params = {}, = {}) req = build_request(:describe_recipe, params) req.send_request() end |
#describe_ruleset(params = {}) ⇒ Types::DescribeRulesetResponse
Retrieves detailed information about the ruleset.
1784 1785 1786 1787 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1784 def describe_ruleset(params = {}, = {}) req = build_request(:describe_ruleset, params) req.send_request() end |
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Returns the definition of a specific DataBrew schedule.
1830 1831 1832 1833 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1830 def describe_schedule(params = {}, = {}) req = build_request(:describe_schedule, params) req.send_request() end |
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the DataBrew datasets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1918 1919 1920 1921 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1918 def list_datasets(params = {}, = {}) req = build_request(:list_datasets, params) req.send_request() end |
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists all of the previous runs of a particular DataBrew job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2007 2008 2009 2010 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2007 def list_job_runs(params = {}, = {}) req = build_request(:list_job_runs, params) req.send_request() end |
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists all of the DataBrew jobs that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2111 2112 2113 2114 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2111 def list_jobs(params = {}, = {}) req = build_request(:list_jobs, params) req.send_request() end |
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Lists all of the DataBrew projects that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2164 2165 2166 2167 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2164 def list_projects(params = {}, = {}) req = build_request(:list_projects, params) req.send_request() end |
#list_recipe_versions(params = {}) ⇒ Types::ListRecipeVersionsResponse
Lists the versions of a particular DataBrew recipe, except for `LATEST_WORKING`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2227 2228 2229 2230 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2227 def list_recipe_versions(params = {}, = {}) req = build_request(:list_recipe_versions, params) req.send_request() end |
#list_recipes(params = {}) ⇒ Types::ListRecipesResponse
Lists all of the DataBrew recipes that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2293 2294 2295 2296 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2293 def list_recipes(params = {}, = {}) req = build_request(:list_recipes, params) req.send_request() end |
#list_rulesets(params = {}) ⇒ Types::ListRulesetsResponse
List all rulesets available in the current account or rulesets associated with a specific resource (dataset).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2351 2352 2353 2354 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2351 def list_rulesets(params = {}, = {}) req = build_request(:list_rulesets, params) req.send_request() end |
#list_schedules(params = {}) ⇒ Types::ListSchedulesResponse
Lists the DataBrew schedules that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2404 2405 2406 2407 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2404 def list_schedules(params = {}, = {}) req = build_request(:list_schedules, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags for a DataBrew resource.
2434 2435 2436 2437 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2434 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#publish_recipe(params = {}) ⇒ Types::PublishRecipeResponse
Publishes a new version of a DataBrew recipe.
2467 2468 2469 2470 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2467 def publish_recipe(params = {}, = {}) req = build_request(:publish_recipe, params) req.send_request() end |
#send_project_session_action(params = {}) ⇒ Types::SendProjectSessionActionResponse
Performs a recipe step within an interactive DataBrew session that's currently open.
2545 2546 2547 2548 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2545 def send_project_session_action(params = {}, = {}) req = build_request(:send_project_session_action, params) req.send_request() end |
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Runs a DataBrew job.
2573 2574 2575 2576 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2573 def start_job_run(params = {}, = {}) req = build_request(:start_job_run, params) req.send_request() end |
#start_project_session(params = {}) ⇒ Types::StartProjectSessionResponse
Creates an interactive session, enabling you to manipulate data in a DataBrew project.
2609 2610 2611 2612 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2609 def start_project_session(params = {}, = {}) req = build_request(:start_project_session, params) req.send_request() end |
#stop_job_run(params = {}) ⇒ Types::StopJobRunResponse
Stops a particular run of a job.
2641 2642 2643 2644 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2641 def stop_job_run(params = {}, = {}) req = build_request(:stop_job_run, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule.
2672 2673 2674 2675 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2672 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a DataBrew resource.
2699 2700 2701 2702 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2699 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Modifies the definition of an existing DataBrew dataset.
2819 2820 2821 2822 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2819 def update_dataset(params = {}, = {}) req = build_request(:update_dataset, params) req.send_request() end |
#update_profile_job(params = {}) ⇒ Types::UpdateProfileJobResponse
Modifies the definition of an existing profile job.
2967 2968 2969 2970 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2967 def update_profile_job(params = {}, = {}) req = build_request(:update_profile_job, params) req.send_request() end |
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Modifies the definition of an existing DataBrew project.
3010 3011 3012 3013 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3010 def update_project(params = {}, = {}) req = build_request(:update_project, params) req.send_request() end |
#update_recipe(params = {}) ⇒ Types::UpdateRecipeResponse
Modifies the definition of the `LATEST_WORKING` version of a DataBrew recipe.
3064 3065 3066 3067 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3064 def update_recipe(params = {}, = {}) req = build_request(:update_recipe, params) req.send_request() end |
#update_recipe_job(params = {}) ⇒ Types::UpdateRecipeJobResponse
Modifies the definition of an existing DataBrew recipe job.
3195 3196 3197 3198 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3195 def update_recipe_job(params = {}, = {}) req = build_request(:update_recipe_job, params) req.send_request() end |
#update_ruleset(params = {}) ⇒ Types::UpdateRulesetResponse
Updates specified ruleset.
3252 3253 3254 3255 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3252 def update_ruleset(params = {}, = {}) req = build_request(:update_ruleset, params) req.send_request() end |
#update_schedule(params = {}) ⇒ Types::UpdateScheduleResponse
Modifies the definition of an existing DataBrew schedule.
3294 3295 3296 3297 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3294 def update_schedule(params = {}, = {}) req = build_request(:update_schedule, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3318 3319 3320 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3318 def waiter_names [] end |