Class: Aws::GlueDataBrew::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::GlueDataBrew::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-gluedatabrew/client.rb
Overview
An API client for GlueDataBrew. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::GlueDataBrew::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_delete_recipe_version(params = {}) ⇒ Types::BatchDeleteRecipeVersionResponse
Deletes one or more versions of a recipe at a time.
-
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new DataBrew dataset.
-
#create_profile_job(params = {}) ⇒ Types::CreateProfileJobResponse
Creates a new job to analyze a dataset and create its data profile.
-
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a new DataBrew project.
-
#create_recipe(params = {}) ⇒ Types::CreateRecipeResponse
Creates a new DataBrew recipe.
-
#create_recipe_job(params = {}) ⇒ Types::CreateRecipeJobResponse
Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe.
-
#create_ruleset(params = {}) ⇒ Types::CreateRulesetResponse
Creates a new ruleset that can be used in a profile job to validate the data quality of a dataset.
-
#create_schedule(params = {}) ⇒ Types::CreateScheduleResponse
Creates a new schedule for one or more DataBrew jobs.
-
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a dataset from DataBrew.
-
#delete_job(params = {}) ⇒ Types::DeleteJobResponse
Deletes the specified DataBrew job.
-
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes an existing DataBrew project.
-
#delete_recipe_version(params = {}) ⇒ Types::DeleteRecipeVersionResponse
Deletes a single version of a DataBrew recipe.
-
#delete_ruleset(params = {}) ⇒ Types::DeleteRulesetResponse
Deletes a ruleset.
-
#delete_schedule(params = {}) ⇒ Types::DeleteScheduleResponse
Deletes the specified DataBrew schedule.
-
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns the definition of a specific DataBrew dataset.
-
#describe_job(params = {}) ⇒ Types::DescribeJobResponse
Returns the definition of a specific DataBrew job.
-
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Represents one run of a DataBrew job.
-
#describe_project(params = {}) ⇒ Types::DescribeProjectResponse
Returns the definition of a specific DataBrew project.
-
#describe_recipe(params = {}) ⇒ Types::DescribeRecipeResponse
Returns the definition of a specific DataBrew recipe corresponding to a particular version.
-
#describe_ruleset(params = {}) ⇒ Types::DescribeRulesetResponse
Retrieves detailed information about the ruleset.
-
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Returns the definition of a specific DataBrew schedule.
-
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the DataBrew datasets.
-
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists all of the previous runs of a particular DataBrew job.
-
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists all of the DataBrew jobs that are defined.
-
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Lists all of the DataBrew projects that are defined.
-
#list_recipe_versions(params = {}) ⇒ Types::ListRecipeVersionsResponse
Lists the versions of a particular DataBrew recipe, except for `LATEST_WORKING`.
-
#list_recipes(params = {}) ⇒ Types::ListRecipesResponse
Lists all of the DataBrew recipes that are defined.
-
#list_rulesets(params = {}) ⇒ Types::ListRulesetsResponse
List all rulesets available in the current account or rulesets associated with a specific resource (dataset).
-
#list_schedules(params = {}) ⇒ Types::ListSchedulesResponse
Lists the DataBrew schedules that are defined.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags for a DataBrew resource.
-
#publish_recipe(params = {}) ⇒ Types::PublishRecipeResponse
Publishes a new version of a DataBrew recipe.
-
#send_project_session_action(params = {}) ⇒ Types::SendProjectSessionActionResponse
Performs a recipe step within an interactive DataBrew session that's currently open.
-
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Runs a DataBrew job.
-
#start_project_session(params = {}) ⇒ Types::StartProjectSessionResponse
Creates an interactive session, enabling you to manipulate data in a DataBrew project.
-
#stop_job_run(params = {}) ⇒ Types::StopJobRunResponse
Stops a particular run of a job.
-
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule.
-
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a DataBrew resource.
-
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Modifies the definition of an existing DataBrew dataset.
-
#update_profile_job(params = {}) ⇒ Types::UpdateProfileJobResponse
Modifies the definition of an existing profile job.
-
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Modifies the definition of an existing DataBrew project.
-
#update_recipe(params = {}) ⇒ Types::UpdateRecipeResponse
Modifies the definition of the `LATEST_WORKING` version of a DataBrew recipe.
-
#update_recipe_job(params = {}) ⇒ Types::UpdateRecipeJobResponse
Modifies the definition of an existing DataBrew recipe job.
-
#update_ruleset(params = {}) ⇒ Types::UpdateRulesetResponse
Updates specified ruleset.
-
#update_schedule(params = {}) ⇒ Types::UpdateScheduleResponse
Modifies the definition of an existing DataBrew schedule.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
344 345 346 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 344 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3323 3324 3325 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3323 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3326 3327 3328 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3326 def errors_module Errors end |
Instance Method Details
#batch_delete_recipe_version(params = {}) ⇒ Types::BatchDeleteRecipeVersionResponse
Deletes one or more versions of a recipe at a time.
The entire request will be rejected if:
-
The recipe does not exist.
-
There is an invalid version identifier in the list of versions.
-
The version list is empty.
-
The version list size exceeds 50.
-
The version list contains duplicate entries.
The request will complete successfully, but with partial failures, if:
-
A version does not exist.
-
A version is being used by a job.
-
You specify `LATEST_WORKING`, but it's being used by a project.
-
The version fails to be deleted.
The `LATEST_WORKING` version will only be deleted if the recipe has no other versions. If you try to delete `LATEST_WORKING` while other versions exist (or if they can't be deleted), then `LATEST_WORKING` will be listed as partial failure in the response.
411 412 413 414 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 411 def batch_delete_recipe_version(params = {}, = {}) req = build_request(:batch_delete_recipe_version, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3301 3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3301 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-gluedatabrew' context[:gem_version] = '1.19.0' Seahorse::Client::Request.new(handlers, context) end |
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new DataBrew dataset.
538 539 540 541 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 538 def create_dataset(params = {}, = {}) req = build_request(:create_dataset, params) req.send_request() end |
#create_profile_job(params = {}) ⇒ Types::CreateProfileJobResponse
Creates a new job to analyze a dataset and create its data profile.
697 698 699 700 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 697 def create_profile_job(params = {}, = {}) req = build_request(:create_profile_job, params) req.send_request() end |
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a new DataBrew project.
753 754 755 756 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 753 def create_project(params = {}, = {}) req = build_request(:create_project, params) req.send_request() end |
#create_recipe(params = {}) ⇒ Types::CreateRecipeResponse
Creates a new DataBrew recipe.
814 815 816 817 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 814 def create_recipe(params = {}, = {}) req = build_request(:create_recipe, params) req.send_request() end |
#create_recipe_job(params = {}) ⇒ Types::CreateRecipeJobResponse
Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe
969 970 971 972 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 969 def create_recipe_job(params = {}, = {}) req = build_request(:create_recipe_job, params) req.send_request() end |
#create_ruleset(params = {}) ⇒ Types::CreateRulesetResponse
Creates a new ruleset that can be used in a profile job to validate the data quality of a dataset.
1039 1040 1041 1042 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1039 def create_ruleset(params = {}, = {}) req = build_request(:create_ruleset, params) req.send_request() end |
#create_schedule(params = {}) ⇒ Types::CreateScheduleResponse
Creates a new schedule for one or more DataBrew jobs. Jobs can be run at a specific date and time, or at regular intervals.
1089 1090 1091 1092 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1089 def create_schedule(params = {}, = {}) req = build_request(:create_schedule, params) req.send_request() end |
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a dataset from DataBrew.
1117 1118 1119 1120 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1117 def delete_dataset(params = {}, = {}) req = build_request(:delete_dataset, params) req.send_request() end |
#delete_job(params = {}) ⇒ Types::DeleteJobResponse
Deletes the specified DataBrew job.
1145 1146 1147 1148 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1145 def delete_job(params = {}, = {}) req = build_request(:delete_job, params) req.send_request() end |
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes an existing DataBrew project.
1173 1174 1175 1176 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1173 def delete_project(params = {}, = {}) req = build_request(:delete_project, params) req.send_request() end |
#delete_recipe_version(params = {}) ⇒ Types::DeleteRecipeVersionResponse
Deletes a single version of a DataBrew recipe.
1209 1210 1211 1212 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1209 def delete_recipe_version(params = {}, = {}) req = build_request(:delete_recipe_version, params) req.send_request() end |
#delete_ruleset(params = {}) ⇒ Types::DeleteRulesetResponse
Deletes a ruleset.
1237 1238 1239 1240 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1237 def delete_ruleset(params = {}, = {}) req = build_request(:delete_ruleset, params) req.send_request() end |
#delete_schedule(params = {}) ⇒ Types::DeleteScheduleResponse
Deletes the specified DataBrew schedule.
1265 1266 1267 1268 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1265 def delete_schedule(params = {}, = {}) req = build_request(:delete_schedule, params) req.send_request() end |
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns the definition of a specific DataBrew dataset.
1353 1354 1355 1356 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1353 def describe_dataset(params = {}, = {}) req = build_request(:describe_dataset, params) req.send_request() end |
#describe_job(params = {}) ⇒ Types::DescribeJobResponse
Returns the definition of a specific DataBrew job.
1481 1482 1483 1484 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1481 def describe_job(params = {}, = {}) req = build_request(:describe_job, params) req.send_request() end |
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Represents one run of a DataBrew job.
1602 1603 1604 1605 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1602 def describe_job_run(params = {}, = {}) req = build_request(:describe_job_run, params) req.send_request() end |
#describe_project(params = {}) ⇒ Types::DescribeProjectResponse
Returns the definition of a specific DataBrew project.
1658 1659 1660 1661 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1658 def describe_project(params = {}, = {}) req = build_request(:describe_project, params) req.send_request() end |
#describe_recipe(params = {}) ⇒ Types::DescribeRecipeResponse
Returns the definition of a specific DataBrew recipe corresponding to a particular version.
1724 1725 1726 1727 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1724 def describe_recipe(params = {}, = {}) req = build_request(:describe_recipe, params) req.send_request() end |
#describe_ruleset(params = {}) ⇒ Types::DescribeRulesetResponse
Retrieves detailed information about the ruleset.
1782 1783 1784 1785 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1782 def describe_ruleset(params = {}, = {}) req = build_request(:describe_ruleset, params) req.send_request() end |
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Returns the definition of a specific DataBrew schedule.
1828 1829 1830 1831 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1828 def describe_schedule(params = {}, = {}) req = build_request(:describe_schedule, params) req.send_request() end |
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the DataBrew datasets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1916 1917 1918 1919 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 1916 def list_datasets(params = {}, = {}) req = build_request(:list_datasets, params) req.send_request() end |
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists all of the previous runs of a particular DataBrew job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2005 2006 2007 2008 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2005 def list_job_runs(params = {}, = {}) req = build_request(:list_job_runs, params) req.send_request() end |
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists all of the DataBrew jobs that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2109 2110 2111 2112 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2109 def list_jobs(params = {}, = {}) req = build_request(:list_jobs, params) req.send_request() end |
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Lists all of the DataBrew projects that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2162 2163 2164 2165 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2162 def list_projects(params = {}, = {}) req = build_request(:list_projects, params) req.send_request() end |
#list_recipe_versions(params = {}) ⇒ Types::ListRecipeVersionsResponse
Lists the versions of a particular DataBrew recipe, except for `LATEST_WORKING`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2225 2226 2227 2228 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2225 def list_recipe_versions(params = {}, = {}) req = build_request(:list_recipe_versions, params) req.send_request() end |
#list_recipes(params = {}) ⇒ Types::ListRecipesResponse
Lists all of the DataBrew recipes that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2291 2292 2293 2294 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2291 def list_recipes(params = {}, = {}) req = build_request(:list_recipes, params) req.send_request() end |
#list_rulesets(params = {}) ⇒ Types::ListRulesetsResponse
List all rulesets available in the current account or rulesets associated with a specific resource (dataset).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2349 2350 2351 2352 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2349 def list_rulesets(params = {}, = {}) req = build_request(:list_rulesets, params) req.send_request() end |
#list_schedules(params = {}) ⇒ Types::ListSchedulesResponse
Lists the DataBrew schedules that are defined.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2402 2403 2404 2405 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2402 def list_schedules(params = {}, = {}) req = build_request(:list_schedules, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags for a DataBrew resource.
2432 2433 2434 2435 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2432 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#publish_recipe(params = {}) ⇒ Types::PublishRecipeResponse
Publishes a new version of a DataBrew recipe.
2465 2466 2467 2468 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2465 def publish_recipe(params = {}, = {}) req = build_request(:publish_recipe, params) req.send_request() end |
#send_project_session_action(params = {}) ⇒ Types::SendProjectSessionActionResponse
Performs a recipe step within an interactive DataBrew session that's currently open.
2543 2544 2545 2546 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2543 def send_project_session_action(params = {}, = {}) req = build_request(:send_project_session_action, params) req.send_request() end |
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Runs a DataBrew job.
2571 2572 2573 2574 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2571 def start_job_run(params = {}, = {}) req = build_request(:start_job_run, params) req.send_request() end |
#start_project_session(params = {}) ⇒ Types::StartProjectSessionResponse
Creates an interactive session, enabling you to manipulate data in a DataBrew project.
2607 2608 2609 2610 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2607 def start_project_session(params = {}, = {}) req = build_request(:start_project_session, params) req.send_request() end |
#stop_job_run(params = {}) ⇒ Types::StopJobRunResponse
Stops a particular run of a job.
2639 2640 2641 2642 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2639 def stop_job_run(params = {}, = {}) req = build_request(:stop_job_run, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule.
2670 2671 2672 2673 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2670 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a DataBrew resource.
2697 2698 2699 2700 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2697 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Modifies the definition of an existing DataBrew dataset.
2817 2818 2819 2820 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2817 def update_dataset(params = {}, = {}) req = build_request(:update_dataset, params) req.send_request() end |
#update_profile_job(params = {}) ⇒ Types::UpdateProfileJobResponse
Modifies the definition of an existing profile job.
2965 2966 2967 2968 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 2965 def update_profile_job(params = {}, = {}) req = build_request(:update_profile_job, params) req.send_request() end |
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Modifies the definition of an existing DataBrew project.
3008 3009 3010 3011 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3008 def update_project(params = {}, = {}) req = build_request(:update_project, params) req.send_request() end |
#update_recipe(params = {}) ⇒ Types::UpdateRecipeResponse
Modifies the definition of the `LATEST_WORKING` version of a DataBrew recipe.
3062 3063 3064 3065 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3062 def update_recipe(params = {}, = {}) req = build_request(:update_recipe, params) req.send_request() end |
#update_recipe_job(params = {}) ⇒ Types::UpdateRecipeJobResponse
Modifies the definition of an existing DataBrew recipe job.
3193 3194 3195 3196 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3193 def update_recipe_job(params = {}, = {}) req = build_request(:update_recipe_job, params) req.send_request() end |
#update_ruleset(params = {}) ⇒ Types::UpdateRulesetResponse
Updates specified ruleset.
3250 3251 3252 3253 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3250 def update_ruleset(params = {}, = {}) req = build_request(:update_ruleset, params) req.send_request() end |
#update_schedule(params = {}) ⇒ Types::UpdateScheduleResponse
Modifies the definition of an existing DataBrew schedule.
3292 3293 3294 3295 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3292 def update_schedule(params = {}, = {}) req = build_request(:update_schedule, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3316 3317 3318 |
# File 'lib/aws-sdk-gluedatabrew/client.rb', line 3316 def waiter_names [] end |