Class: Aws::GlueDataBrew::Types::CreateRecipeJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::CreateRecipeJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
When making an API call, you may pass CreateRecipeJobRequest data as a hash:
{
dataset_name: "DatasetName",
encryption_key_arn: "EncryptionKeyArn",
encryption_mode: "SSE-KMS", # accepts SSE-KMS, SSE-S3
name: "JobName", # required
log_subscription: "ENABLE", # accepts ENABLE, DISABLE
max_capacity: 1,
max_retries: 1,
outputs: [
{
compression_format: "GZIP", # accepts GZIP, LZ4, SNAPPY, BZIP2, DEFLATE, LZO, BROTLI, ZSTD, ZLIB
format: "CSV", # accepts CSV, JSON, PARQUET, GLUEPARQUET, AVRO, ORC, XML, TABLEAUHYPER
partition_columns: ["ColumnName"],
location: { # required
bucket: "Bucket", # required
key: "Key",
bucket_owner: "BucketOwner",
},
overwrite: false,
format_options: {
csv: {
delimiter: "Delimiter",
},
},
},
],
data_catalog_outputs: [
{
catalog_id: "CatalogId",
database_name: "DatabaseName", # required
table_name: "TableName", # required
s3_options: {
location: { # required
bucket: "Bucket", # required
key: "Key",
bucket_owner: "BucketOwner",
},
},
database_options: {
temp_directory: {
bucket: "Bucket", # required
key: "Key",
bucket_owner: "BucketOwner",
},
table_name: "DatabaseTableName", # required
},
overwrite: false,
},
],
database_outputs: [
{
glue_connection_name: "GlueConnectionName", # required
database_options: { # required
temp_directory: {
bucket: "Bucket", # required
key: "Key",
bucket_owner: "BucketOwner",
},
table_name: "DatabaseTableName", # required
},
database_output_mode: "NEW_TABLE", # accepts NEW_TABLE
},
],
project_name: "ProjectName",
recipe_reference: {
name: "RecipeName", # required
recipe_version: "RecipeVersion",
},
role_arn: "Arn", # required
tags: {
"TagKey" => "TagValue",
},
timeout: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_catalog_outputs ⇒ Array<Types::DataCatalogOutput>
One or more artifacts that represent the Glue Data Catalog output from running the job.
-
#database_outputs ⇒ Array<Types::DatabaseOutput>
Represents a list of JDBC database output objects which defines the output destination for a DataBrew recipe job to write to.
-
#dataset_name ⇒ String
The name of the dataset that this job processes.
-
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of an encryption key that is used to protect the job.
-
#encryption_mode ⇒ String
The encryption mode for the job, which can be one of the following:.
-
#log_subscription ⇒ String
Enables or disables Amazon CloudWatch logging for the job.
-
#max_capacity ⇒ Integer
The maximum number of nodes that DataBrew can consume when the job processes data.
-
#max_retries ⇒ Integer
The maximum number of times to retry the job after a job run fails.
-
#name ⇒ String
A unique name for the job.
-
#outputs ⇒ Array<Types::Output>
One or more artifacts that represent the output from running the job.
-
#project_name ⇒ String
Either the name of an existing project, or a combination of a recipe and a dataset to associate with the recipe.
-
#recipe_reference ⇒ Types::RecipeReference
Represents the name and version of a DataBrew recipe.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role to be assumed when DataBrew runs the job.
-
#tags ⇒ Hash<String,String>
Metadata tags to apply to this job.
-
#timeout ⇒ Integer
The job's timeout in minutes.
Instance Attribute Details
#data_catalog_outputs ⇒ Array<Types::DataCatalogOutput>
One or more artifacts that represent the Glue Data Catalog output from running the job.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#database_outputs ⇒ Array<Types::DatabaseOutput>
Represents a list of JDBC database output objects which defines the output destination for a DataBrew recipe job to write to.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#dataset_name ⇒ String
The name of the dataset that this job processes.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of an encryption key that is used to protect the job.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#encryption_mode ⇒ String
The encryption mode for the job, which can be one of the following:
-
`SSE-KMS` - Server-side encryption with keys managed by KMS.
-
`SSE-S3` - Server-side encryption with keys managed by Amazon S3.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#log_subscription ⇒ String
Enables or disables Amazon CloudWatch logging for the job. If logging is enabled, CloudWatch writes one log stream for each job run.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Integer
The maximum number of nodes that DataBrew can consume when the job processes data.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#max_retries ⇒ Integer
The maximum number of times to retry the job after a job run fails.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A unique name for the job. Valid characters are alphanumeric (A-Z, a-z, 0-9), hyphen (-), period (.), and space.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::Output>
One or more artifacts that represent the output from running the job.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
Either the name of an existing project, or a combination of a recipe and a dataset to associate with the recipe.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#recipe_reference ⇒ Types::RecipeReference
Represents the name and version of a DataBrew recipe.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role to be assumed when DataBrew runs the job.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata tags to apply to this job.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The job's timeout in minutes. A job that attempts to run longer than this timeout period ends with a status of `TIMEOUT`.
787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 787 class CreateRecipeJobRequest < Struct.new( :dataset_name, :encryption_key_arn, :encryption_mode, :name, :log_subscription, :max_capacity, :max_retries, :outputs, :data_catalog_outputs, :database_outputs, :project_name, :recipe_reference, :role_arn, :tags, :timeout) SENSITIVE = [] include Aws::Structure end |