Class: Aws::GlueDataBrew::Types::DescribeScheduleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GlueDataBrew::Types::DescribeScheduleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gluedatabrew/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_date ⇒ Time
The date and time that the schedule was created.
-
#created_by ⇒ String
The identifier (user name) of the user who created the schedule.
-
#cron_expression ⇒ String
The date or dates and time or times when the jobs are to be run for the schedule.
-
#job_names ⇒ Array<String>
The name or names of one or more jobs to be run by using the schedule.
-
#last_modified_by ⇒ String
The identifier (user name) of the user who last modified the schedule.
-
#last_modified_date ⇒ Time
The date and time that the schedule was last modified.
-
#name ⇒ String
The name of the schedule.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the schedule.
-
#tags ⇒ Hash<String,String>
Metadata tags associated with this schedule.
Instance Attribute Details
#create_date ⇒ Time
The date and time that the schedule was created.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2457 class DescribeScheduleResponse < Struct.new( :create_date, :created_by, :job_names, :last_modified_by, :last_modified_date, :resource_arn, :cron_expression, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The identifier (user name) of the user who created the schedule.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2457 class DescribeScheduleResponse < Struct.new( :create_date, :created_by, :job_names, :last_modified_by, :last_modified_date, :resource_arn, :cron_expression, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#cron_expression ⇒ String
The date or dates and time or times when the jobs are to be run for the schedule. For more information, see [Cron expressions] in the *Glue DataBrew Developer Guide*.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2457 class DescribeScheduleResponse < Struct.new( :create_date, :created_by, :job_names, :last_modified_by, :last_modified_date, :resource_arn, :cron_expression, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#job_names ⇒ Array<String>
The name or names of one or more jobs to be run by using the schedule.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2457 class DescribeScheduleResponse < Struct.new( :create_date, :created_by, :job_names, :last_modified_by, :last_modified_date, :resource_arn, :cron_expression, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ String
The identifier (user name) of the user who last modified the schedule.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2457 class DescribeScheduleResponse < Struct.new( :create_date, :created_by, :job_names, :last_modified_by, :last_modified_date, :resource_arn, :cron_expression, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date and time that the schedule was last modified.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2457 class DescribeScheduleResponse < Struct.new( :create_date, :created_by, :job_names, :last_modified_by, :last_modified_date, :resource_arn, :cron_expression, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the schedule.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2457 class DescribeScheduleResponse < Struct.new( :create_date, :created_by, :job_names, :last_modified_by, :last_modified_date, :resource_arn, :cron_expression, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the schedule.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2457 class DescribeScheduleResponse < Struct.new( :create_date, :created_by, :job_names, :last_modified_by, :last_modified_date, :resource_arn, :cron_expression, :tags, :name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata tags associated with this schedule.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-gluedatabrew/types.rb', line 2457 class DescribeScheduleResponse < Struct.new( :create_date, :created_by, :job_names, :last_modified_by, :last_modified_date, :resource_arn, :cron_expression, :tags, :name) SENSITIVE = [] include Aws::Structure end |